[nautilus-actions] NAPivot class is renamed to FMAPivot



commit 9c6d9cb8738b33fc48da178c3a113425dc6c87ce
Author: Pierre Wieser <pwieser trychlos org>
Date:   Tue Sep 8 11:59:07 2015 +0200

    NAPivot class is renamed to FMAPivot

 src/api/fma-iimporter.h              |    2 +-
 src/core/Makefile.am                 |    4 +-
 src/core/fma-exporter.c              |   28 +++---
 src/core/fma-exporter.h              |   10 +-
 src/core/fma-icontext.c              |    2 +-
 src/core/fma-iio-provider.c          |    2 +-
 src/core/fma-importer-ask.h          |    4 +-
 src/core/fma-importer.c              |   14 +-
 src/core/fma-importer.h              |    4 +-
 src/core/fma-io-provider.c           |   90 ++++++++--------
 src/core/fma-io-provider.h           |   14 +-
 src/core/fma-iprefs.h                |    2 +-
 src/core/fma-module.c                |    2 +-
 src/core/fma-module.h                |    8 +-
 src/core/{na-pivot.c => fma-pivot.c} |  200 +++++++++++++++++-----------------
 src/core/{na-pivot.h => fma-pivot.h} |   86 +++++++-------
 src/core/na-updater.c                |   18 ++--
 src/core/na-updater.h                |    8 +-
 src/io-desktop/nadp-monitor.h        |    2 +-
 src/nact/main.c                      |    2 +-
 src/nact/nact-application.c          |    4 +-
 src/nact/nact-assistant-export.c     |    4 +-
 src/nact/nact-assistant-import.c     |    2 +-
 src/nact/nact-clipboard.c            |    4 +-
 src/nact/nact-export-ask.c           |    2 +-
 src/nact/nact-main-window.c          |    4 +-
 src/nact/nact-menu-file.c            |    2 +-
 src/nact/nact-menu.c                 |    2 +-
 src/nact/nact-preferences-editor.c   |    2 +-
 src/nact/nact-providers-list.c       |    6 +-
 src/nact/nact-tree-ieditable.c       |    2 +-
 src/nact/nact-tree-model-dnd.c       |    2 +-
 src/nact/nact-tree-model.c           |    4 +-
 src/plugin-menu/nautilus-actions.c   |   36 +++---
 src/plugin-menu/nautilus-module.c    |    2 +-
 src/test/test-reader.c               |    8 +-
 src/utils/nautilus-actions-new.c     |    6 +-
 src/utils/nautilus-actions-print.c   |   10 +-
 src/utils/nautilus-actions-run.c     |   14 +-
 39 files changed, 309 insertions(+), 309 deletions(-)
---
diff --git a/src/api/fma-iimporter.h b/src/api/fma-iimporter.h
index 0daef8d..f696a76 100644
--- a/src/api/fma-iimporter.h
+++ b/src/api/fma-iimporter.h
@@ -197,7 +197,7 @@ typedef struct {
  *     </para>
  *   </listitem>
  * </itemizedlist>
- * Items which may have been loaded by NAPivot at the start of the
+ * Items which may have been loaded by FMAPivot at the start of the
  * application, and deleted meanwhile, are just ignored.
  *
  * Returns: the already existing #FMAObjectItem with same id, or %NULL.
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index 5b29fdb..a3d21a6 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -111,8 +111,8 @@ libna_core_la_SOURCES = \
        fma-object-profile-factory.c                                                    \
        fma-object-menu.c                                                                       \
        fma-object-menu-factory.c                                                       \
-       na-pivot.c                                                                                      \
-       na-pivot.h                                                                                      \
+       fma-pivot.c                                                                                     \
+       fma-pivot.h                                                                                     \
        na-selected-info.c                                                                      \
        na-selected-info.h                                                                      \
        na-settings.c                                                                           \
diff --git a/src/core/fma-exporter.h b/src/core/fma-exporter.h
index 5989ca4..bffde67 100644
--- a/src/core/fma-exporter.h
+++ b/src/core/fma-exporter.h
@@ -39,29 +39,29 @@
 #include <api/fma-object-api.h>
 
 #include "fma-ioption.h"
-#include "na-pivot.h"
+#include "fma-pivot.h"
 
 G_BEGIN_DECLS
 
 #define EXPORTER_FORMAT_ASK                            "Ask"
 #define EXPORTER_FORMAT_NOEXPORT               "NoExport"
 
-GList        *fma_exporter_get_formats    ( const NAPivot *pivot );
+GList        *fma_exporter_get_formats    ( const FMAPivot *pivot );
 void          fma_exporter_free_formats   ( GList *formats );
 FMAIOption   *fma_exporter_get_ask_option ( void );
 
-gchar        *fma_exporter_to_buffer      ( const NAPivot *pivot,
+gchar        *fma_exporter_to_buffer      ( const FMAPivot *pivot,
                                             const FMAObjectItem *item,
                                             const gchar *format,
                                             GSList **messages );
 
-gchar        *fma_exporter_to_file        ( const NAPivot *pivot,
+gchar        *fma_exporter_to_file        ( const FMAPivot *pivot,
                                             const FMAObjectItem *item,
                                             const gchar *folder_uri,
                                             const gchar *format,
                                             GSList **messages );
 
-FMAIExporter *fma_exporter_find_for_format( const NAPivot *pivot,
+FMAIExporter *fma_exporter_find_for_format( const FMAPivot *pivot,
                                                    const gchar *format );
 
 G_END_DECLS
diff --git a/src/core/fma-icontext.c b/src/core/fma-icontext.c
index b41f908..cfd5e5d 100644
--- a/src/core/fma-icontext.c
+++ b/src/core/fma-icontext.c
@@ -208,7 +208,7 @@ fma_icontext_are_equal( const FMAIContext *a, const FMAIContext *b )
  * items.
  *
  * This function is called by <methodname>build_nautilus_menus</methodname>
- * plugin function for each item found in NAPivot items list, and, when this
+ * plugin function for each item found in FMAPivot items list, and, when this
  * an action, for each profile of this action.
  *
  * Returns: %TRUE if this @context succeeds to all tests and is so a
diff --git a/src/core/fma-iio-provider.c b/src/core/fma-iio-provider.c
index 9f29b1c..8e1be74 100644
--- a/src/core/fma-iio-provider.c
+++ b/src/core/fma-iio-provider.c
@@ -200,7 +200,7 @@ do_is_able_to_write( const FMAIIOProvider *instance )
  * to ask the user if he is willing to reload such a current list (and
  * this is the way &nact; has chosen to deal with this message).
  *
- * Note that application NAPivot/NAUpdater pivot is typically the only
+ * Note that application FMAPivot/NAUpdater pivot is typically the only
  * object connected to this signal. It acts so as a filtering proxy,
  * re-emitting its own 'items-changed' signal for a whole set of detected
  * underlying modifications.
diff --git a/src/core/fma-importer-ask.h b/src/core/fma-importer-ask.h
index 7ef75af..a2013b4 100644
--- a/src/core/fma-importer-ask.h
+++ b/src/core/fma-importer-ask.h
@@ -43,7 +43,7 @@
 
 #include <api/fma-object-item.h>
 
-#include "na-pivot.h"
+#include "fma-pivot.h"
 
 G_BEGIN_DECLS
 
@@ -77,7 +77,7 @@ typedef struct {
        gchar          *uri;
        guint           count;
        gboolean        keep_choice;
-       const NAPivot *pivot;
+       const FMAPivot *pivot;
 }
        FMAImporterAskUserParms;
 
diff --git a/src/core/fma-importer.h b/src/core/fma-importer.h
index be2d087..fa0b82b 100644
--- a/src/core/fma-importer.h
+++ b/src/core/fma-importer.h
@@ -61,7 +61,7 @@
 #include <api/fma-object-item.h>
 
 #include "fma-ioption.h"
-#include "na-pivot.h"
+#include "fma-pivot.h"
 
 G_BEGIN_DECLS
 
@@ -141,7 +141,7 @@ typedef struct {
 }
        FMAImporterResult;
 
-GList      *fma_importer_import_from_uris( const NAPivot *pivot, FMAImporterParms *parms );
+GList      *fma_importer_import_from_uris( const FMAPivot *pivot, FMAImporterParms *parms );
 
 void        fma_importer_free_result     ( FMAImporterResult *result );
 
diff --git a/src/core/fma-io-provider.h b/src/core/fma-io-provider.h
index df5b044..6767f27 100644
--- a/src/core/fma-io-provider.h
+++ b/src/core/fma-io-provider.h
@@ -59,7 +59,7 @@
  * and the whole configuration must not have been locked by an admin.
  */
 
-#include "na-pivot.h"
+#include "fma-pivot.h"
 
 G_BEGIN_DECLS
 
@@ -95,19 +95,19 @@ typedef struct {
 
 GType          fma_io_provider_get_type                 ( void );
 
-FMAIOProvider *fma_io_provider_find_writable_io_provider( const NAPivot *pivot );
-FMAIOProvider *fma_io_provider_find_io_provider_by_id   ( const NAPivot *pivot, const gchar *id );
-const GList   *fma_io_provider_get_io_providers_list    ( const NAPivot *pivot );
+FMAIOProvider *fma_io_provider_find_writable_io_provider( const FMAPivot *pivot );
+FMAIOProvider *fma_io_provider_find_io_provider_by_id   ( const FMAPivot *pivot, const gchar *id );
+const GList   *fma_io_provider_get_io_providers_list    ( const FMAPivot *pivot );
 void           fma_io_provider_unref_io_providers_list  ( void );
 
 gchar         *fma_io_provider_get_id                   ( const FMAIOProvider *provider );
 gchar         *fma_io_provider_get_name                 ( const FMAIOProvider *provider );
 gboolean       fma_io_provider_is_available             ( const FMAIOProvider *provider );
-gboolean       fma_io_provider_is_conf_readable         ( const FMAIOProvider *provider, const NAPivot 
*pivot, gboolean *mandatory );
-gboolean       fma_io_provider_is_conf_writable         ( const FMAIOProvider *provider, const NAPivot 
*pivot, gboolean *mandatory );
+gboolean       fma_io_provider_is_conf_readable         ( const FMAIOProvider *provider, const FMAPivot 
*pivot, gboolean *mandatory );
+gboolean       fma_io_provider_is_conf_writable         ( const FMAIOProvider *provider, const FMAPivot 
*pivot, gboolean *mandatory );
 gboolean       fma_io_provider_is_finally_writable      ( const FMAIOProvider *provider, guint *reason );
 
-GList         *fma_io_provider_load_items               ( const NAPivot *pivot, guint loadable_set, GSList 
**messages );
+GList         *fma_io_provider_load_items               ( const FMAPivot *pivot, guint loadable_set, GSList 
**messages );
 
 guint          fma_io_provider_write_item               ( const FMAIOProvider *provider, const FMAObjectItem 
*item, GSList **messages );
 guint          fma_io_provider_delete_item              ( const FMAIOProvider *provider, const FMAObjectItem 
*item, GSList **messages );
diff --git a/src/core/fma-iprefs.h b/src/core/fma-iprefs.h
index 995ff0b..9772e82 100644
--- a/src/core/fma-iprefs.h
+++ b/src/core/fma-iprefs.h
@@ -39,7 +39,7 @@
  * preferences.
  */
 
-#include "na-pivot.h"
+#include "fma-pivot.h"
 
 G_BEGIN_DECLS
 
diff --git a/src/core/fma-module.c b/src/core/fma-module.c
index 4a72206..19ae052 100644
--- a/src/core/fma-module.c
+++ b/src/core/fma-module.c
@@ -517,7 +517,7 @@ fma_module_has_id( FMAModule *module, const gchar *id )
  * fma_module_release_modules:
  * @modules: the list of loaded modules.
  *
- * Release resources allocated to the loaded modules on #NAPivot dispose.
+ * Release resources allocated to the loaded modules on #FMAPivot dispose.
  */
 void
 fma_module_release_modules( GList *modules )
diff --git a/src/core/fma-module.h b/src/core/fma-module.h
index dcd4a50..bb83e3f 100644
--- a/src/core/fma-module.h
+++ b/src/core/fma-module.h
@@ -49,15 +49,15 @@
  * which are dynamically instantiated at plugin initial-load time.
  *
  * So the dynamic is as follows:
- * - NAPivot scans for the PKGLIBDIR directory, trying to dynamically
+ * - FMAPivot scans for the PKGLIBDIR directory, trying to dynamically
  *   load all found libraries
  * - to be considered as a N-A plugin, a library must implement some
  *   functions (see api/na-api.h)
- * - for each found plugin, NAPivot calls na_api_list_types() which
+ * - for each found plugin, FMAPivot calls na_api_list_types() which
  *   returns the type of GObjects implemented in the plugin
- * - NAPivot dynamically instantiates a GObject for each returned GType.
+ * - FMAPivot dynamically instantiates a GObject for each returned GType.
  *
- * After that, when NAPivot wants to access, say to FMAIIOProvider
+ * After that, when FMAPivot wants to access, say to FMAIIOProvider
  * interfaces, it asks each module for its list of objects which implement
  * this given interface.
  * Interface API is then called against the returned GObject.
diff --git a/src/core/na-pivot.c b/src/core/fma-pivot.c
similarity index 75%
rename from src/core/na-pivot.c
rename to src/core/fma-pivot.c
index adc3418..21576e4 100644
--- a/src/core/na-pivot.c
+++ b/src/core/fma-pivot.c
@@ -38,17 +38,17 @@
 
 #include "fma-io-provider.h"
 #include "fma-module.h"
-#include "na-pivot.h"
+#include "fma-pivot.h"
 
 /* private class data
  */
-struct _NAPivotClassPrivate {
+struct _FMAPivotClassPrivate {
        void *empty;                                            /* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct _NAPivotPrivate {
+struct _FMAPivotPrivate {
        gboolean    dispose_has_run;
 
        guint       loadable_set;
@@ -66,7 +66,7 @@ struct _NAPivotPrivate {
        FMATimeout   change_timeout;
 };
 
-/* NAPivot properties
+/* FMAPivot properties
  */
 enum {
        PRIVOT_PROP_0,
@@ -90,7 +90,7 @@ static gint          st_burst_timeout          = 100;         /* burst timeout in msec
 static gint          st_signals[ LAST_SIGNAL ] = { 0 };
 
 static GType         register_type( void );
-static void          class_init( NAPivotClass *klass );
+static void          class_init( FMAPivotClass *klass );
 static void          instance_init( GTypeInstance *instance, gpointer klass );
 static void          instance_constructed( GObject *object );
 static void          instance_get_property( GObject *object, guint property_id, GValue *value, GParamSpec 
*spec );
@@ -98,13 +98,13 @@ static void          instance_set_property( GObject *object, guint property_id,
 static void          instance_dispose( GObject *object );
 static void          instance_finalize( GObject *object );
 
-static FMAObjectItem *get_item_from_tree( const NAPivot *pivot, GList *tree, const gchar *id );
+static FMAObjectItem *get_item_from_tree( const FMAPivot *pivot, GList *tree, const gchar *id );
 
 /* FMAIIOProvider management */
-static void          on_items_changed_timeout( NAPivot *pivot );
+static void          on_items_changed_timeout( FMAPivot *pivot );
 
 GType
-na_pivot_get_type( void )
+fma_pivot_get_type( void )
 {
        static GType object_type = 0;
 
@@ -118,32 +118,32 @@ na_pivot_get_type( void )
 static GType
 register_type( void )
 {
-       static const gchar *thisfn = "na_pivot_register_type";
+       static const gchar *thisfn = "fma_pivot_register_type";
        GType type;
 
        static GTypeInfo info = {
-               sizeof( NAPivotClass ),
+               sizeof( FMAPivotClass ),
                ( GBaseInitFunc ) NULL,
                ( GBaseFinalizeFunc ) NULL,
                ( GClassInitFunc ) class_init,
                NULL,
                NULL,
-               sizeof( NAPivot ),
+               sizeof( FMAPivot ),
                0,
                ( GInstanceInitFunc ) instance_init
        };
 
        g_debug( "%s", thisfn );
 
-       type = g_type_register_static( G_TYPE_OBJECT, "NAPivot", &info, 0 );
+       type = g_type_register_static( G_TYPE_OBJECT, "FMAPivot", &info, 0 );
 
        return( type );
 }
 
 static void
-class_init( NAPivotClass *klass )
+class_init( FMAPivotClass *klass )
 {
-       static const gchar *thisfn = "na_pivot_class_init";
+       static const gchar *thisfn = "fma_pivot_class_init";
        GObjectClass *object_class;
 
        g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
@@ -172,19 +172,19 @@ class_init( NAPivotClass *klass )
                                        "Hierarchical tree of items",
                                        G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE ));
 
-       klass->private = g_new0( NAPivotClassPrivate, 1 );
+       klass->private = g_new0( FMAPivotClassPrivate, 1 );
 
        /*
-        * NAPivot::pivot-items-changed:
+        * FMAPivot::pivot-items-changed:
         *
-        * This signal is sent by NAPivot at the end of a burst of modifications
+        * This signal is sent by FMAPivot at the end of a burst of modifications
         * as signaled by i/o providers.
         *
         * The signal is registered without any default handler.
         */
        st_signals[ ITEMS_CHANGED ] = g_signal_new(
                                PIVOT_SIGNAL_ITEMS_CHANGED,
-                               NA_TYPE_PIVOT,
+                               FMA_TYPE_PIVOT,
                                G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
                                0,                                                                      /* 
class offset */
                                NULL,                                                           /* 
accumulator */
@@ -197,17 +197,17 @@ class_init( NAPivotClass *klass )
 static void
 instance_init( GTypeInstance *instance, gpointer klass )
 {
-       static const gchar *thisfn = "na_pivot_instance_init";
-       NAPivot *self;
+       static const gchar *thisfn = "fma_pivot_instance_init";
+       FMAPivot *self;
 
-       g_return_if_fail( NA_IS_PIVOT( instance ));
+       g_return_if_fail( FMA_IS_PIVOT( instance ));
 
        g_debug( "%s: instance=%p (%s), klass=%p",
                        thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
 
-       self = NA_PIVOT( instance );
+       self = FMA_PIVOT( instance );
 
-       self->private = g_new0( NAPivotPrivate, 1 );
+       self->private = g_new0( FMAPivotPrivate, 1 );
 
        self->private->dispose_has_run = FALSE;
        self->private->loadable_set = PIVOT_LOAD_NONE;
@@ -225,12 +225,12 @@ instance_init( GTypeInstance *instance, gpointer klass )
 static void
 instance_constructed( GObject *object )
 {
-       static const gchar *thisfn = "na_pivot_instance_constructed";
-       NAPivotPrivate *priv;
+       static const gchar *thisfn = "fma_pivot_instance_constructed";
+       FMAPivotPrivate *priv;
 
-       g_return_if_fail( NA_IS_PIVOT( object ));
+       g_return_if_fail( FMA_IS_PIVOT( object ));
 
-       priv = NA_PIVOT( object )->private;
+       priv = FMA_PIVOT( object )->private;
 
        if( !priv->dispose_has_run ){
 
@@ -253,10 +253,10 @@ instance_constructed( GObject *object )
 static void
 instance_get_property( GObject *object, guint property_id, GValue *value, GParamSpec *spec )
 {
-       NAPivot *self;
+       FMAPivot *self;
 
-       g_return_if_fail( NA_IS_PIVOT( object ));
-       self = NA_PIVOT( object );
+       g_return_if_fail( FMA_IS_PIVOT( object ));
+       self = FMA_PIVOT( object );
 
        if( !self->private->dispose_has_run ){
 
@@ -279,10 +279,10 @@ instance_get_property( GObject *object, guint property_id, GValue *value, GParam
 static void
 instance_set_property( GObject *object, guint property_id, const GValue *value, GParamSpec *spec )
 {
-       NAPivot *self;
+       FMAPivot *self;
 
-       g_return_if_fail( NA_IS_PIVOT( object ));
-       self = NA_PIVOT( object );
+       g_return_if_fail( FMA_IS_PIVOT( object ));
+       self = FMA_PIVOT( object );
 
        if( !self->private->dispose_has_run ){
 
@@ -305,12 +305,12 @@ instance_set_property( GObject *object, guint property_id, const GValue *value,
 static void
 instance_dispose( GObject *object )
 {
-       static const gchar *thisfn = "na_pivot_instance_dispose";
-       NAPivot *self;
+       static const gchar *thisfn = "fma_pivot_instance_dispose";
+       FMAPivot *self;
 
-       g_return_if_fail( NA_IS_PIVOT( object ));
+       g_return_if_fail( FMA_IS_PIVOT( object ));
 
-       self = NA_PIVOT( object );
+       self = FMA_PIVOT( object );
 
        if( !self->private->dispose_has_run ){
 
@@ -344,14 +344,14 @@ instance_dispose( GObject *object )
 static void
 instance_finalize( GObject *object )
 {
-       static const gchar *thisfn = "na_pivot_instance_finalize";
-       NAPivot *self;
+       static const gchar *thisfn = "fma_pivot_instance_finalize";
+       FMAPivot *self;
 
-       g_return_if_fail( NA_IS_PIVOT( object ));
+       g_return_if_fail( FMA_IS_PIVOT( object ));
 
        g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
-       self = NA_PIVOT( object );
+       self = FMA_PIVOT( object );
 
        g_free( self->private );
 
@@ -362,7 +362,7 @@ instance_finalize( GObject *object )
 }
 
 /*
- * na_pivot_new:
+ * fma_pivot_new:
  *
  * This object takes care of all items/actions/menus/providers/settings
  * management which is required to correctly handle file manager context
@@ -373,38 +373,38 @@ instance_finalize( GObject *object )
  * - initializing the preferences monitoring.
  *
  * Actual loading of items from i/o providers is delayed until a call
- * to call to na_pivot_load_items() function, so that the caller is able
- * to set its own needed #NAPivot properties (e.g. the loadable set of
+ * to call to fma_pivot_load_items() function, so that the caller is able
+ * to set its own needed #FMAPivot properties (e.g. the loadable set of
  * items).
  *
- * Only one #NAPivot object should be instantiated for a running application.
+ * Only one #FMAPivot object should be instantiated for a running application.
  *
- * Returns: a newly allocated #NAPivot object which should be g_object_unref()
+ * Returns: a newly allocated #FMAPivot object which should be g_object_unref()
  * by the caller at the end of the application.
  */
-NAPivot *
-na_pivot_new( void )
+FMAPivot *
+fma_pivot_new( void )
 {
-       static const gchar *thisfn = "na_pivot_new";
-       NAPivot *pivot;
+       static const gchar *thisfn = "fma_pivot_new";
+       FMAPivot *pivot;
 
        g_debug( "%s", thisfn );
 
-       pivot = g_object_new( NA_TYPE_PIVOT, NULL );
+       pivot = g_object_new( FMA_TYPE_PIVOT, NULL );
 
        return( pivot );
 }
 
 /*
- * na_pivot_dump:
- * @pivot: the #NAPivot object do be dumped.
+ * fma_pivot_dump:
+ * @pivot: the #FMAPivot object do be dumped.
  *
- * Dumps the content of a #NAPivot object.
+ * Dumps the content of a #FMAPivot object.
  */
 void
-na_pivot_dump( const NAPivot *pivot )
+fma_pivot_dump( const FMAPivot *pivot )
 {
-       static const gchar *thisfn = "na_pivot_dump";
+       static const gchar *thisfn = "fma_pivot_dump";
        GList *it;
        int i;
 
@@ -422,8 +422,8 @@ na_pivot_dump( const NAPivot *pivot )
 }
 
 /*
- * na_pivot_get_providers:
- * @pivot: this #NAPivot instance.
+ * fma_pivot_get_providers:
+ * @pivot: this #FMAPivot instance.
  * @type: the type of searched interface.
  * For now, we only have FMA_TYPE_IIO_PROVIDER interfaces.
  *
@@ -432,15 +432,15 @@ na_pivot_dump( const NAPivot *pivot )
  * This function is called by interfaces API in order to find the
  * list of providers registered for their own given interface.
  *
- * The returned list should be release by calling na_pivot_free_providers().
+ * The returned list should be release by calling fma_pivot_free_providers().
  */
 GList *
-na_pivot_get_providers( const NAPivot *pivot, GType type )
+fma_pivot_get_providers( const FMAPivot *pivot, GType type )
 {
-       static const gchar *thisfn = "na_pivot_get_providers";
+       static const gchar *thisfn = "fma_pivot_get_providers";
        GList *list = NULL;
 
-       g_return_val_if_fail( NA_IS_PIVOT( pivot ), NULL );
+       g_return_val_if_fail( FMA_IS_PIVOT( pivot ), NULL );
 
        if( !pivot->private->dispose_has_run ){
 
@@ -454,15 +454,15 @@ na_pivot_get_providers( const NAPivot *pivot, GType type )
 }
 
 /*
- * na_pivot_free_providers:
+ * fma_pivot_free_providers:
  * @providers: a list of providers.
  *
- * Frees a list of providers as returned from na_pivot_get_providers().
+ * Frees a list of providers as returned from fma_pivot_get_providers().
  */
 void
-na_pivot_free_providers( GList *providers )
+fma_pivot_free_providers( GList *providers )
 {
-       static const gchar *thisfn = "na_pivot_free_providers";
+       static const gchar *thisfn = "fma_pivot_free_providers";
 
        g_debug( "%s: providers=%p", thisfn, ( void * ) providers );
 
@@ -470,8 +470,8 @@ na_pivot_free_providers( GList *providers )
 }
 
 /*
- * na_pivot_get_item:
- * @pivot: this #NAPivot instance.
+ * fma_pivot_get_item:
+ * @pivot: this #FMAPivot instance.
  * @id: the required item identifier.
  *
  * Returns the specified item, action or menu.
@@ -479,15 +479,15 @@ na_pivot_free_providers( GList *providers )
  * Returns: the required #FMAObjectItem-derived object, or %NULL if not
  * found.
  *
- * The returned pointer is owned by #NAPivot, and should not be
+ * The returned pointer is owned by #FMAPivot, and should not be
  * g_free() nor g_object_unref() by the caller.
  */
 FMAObjectItem *
-na_pivot_get_item( const NAPivot *pivot, const gchar *id )
+fma_pivot_get_item( const FMAPivot *pivot, const gchar *id )
 {
        FMAObjectItem *object = NULL;
 
-       g_return_val_if_fail( NA_IS_PIVOT( pivot ), NULL );
+       g_return_val_if_fail( FMA_IS_PIVOT( pivot ), NULL );
 
        if( !pivot->private->dispose_has_run ){
 
@@ -502,7 +502,7 @@ na_pivot_get_item( const NAPivot *pivot, const gchar *id )
 }
 
 static FMAObjectItem *
-get_item_from_tree( const NAPivot *pivot, GList *tree, const gchar *id )
+get_item_from_tree( const FMAPivot *pivot, GList *tree, const gchar *id )
 {
        GList *subitems, *ia;
        FMAObjectItem *found = NULL;
@@ -525,20 +525,20 @@ get_item_from_tree( const NAPivot *pivot, GList *tree, const gchar *id )
 }
 
 /*
- * na_pivot_get_items:
- * @pivot: this #NAPivot instance.
+ * fma_pivot_get_items:
+ * @pivot: this #FMAPivot instance.
  *
  * Returns: the current configuration tree.
  *
- * The returned list is owned by this #NAPivot object, and should not
+ * The returned list is owned by this #FMAPivot object, and should not
  * be g_free(), nor g_object_unref() by the caller.
  */
 GList *
-na_pivot_get_items( const NAPivot *pivot )
+fma_pivot_get_items( const FMAPivot *pivot )
 {
        GList *tree;
 
-       g_return_val_if_fail( NA_IS_PIVOT( pivot ), NULL );
+       g_return_val_if_fail( FMA_IS_PIVOT( pivot ), NULL );
 
        tree = NULL;
 
@@ -551,18 +551,18 @@ na_pivot_get_items( const NAPivot *pivot )
 }
 
 /*
- * na_pivot_load_items:
- * @pivot: this #NAPivot instance.
+ * fma_pivot_load_items:
+ * @pivot: this #FMAPivot instance.
  *
  * Loads the hierarchical list of items from I/O providers.
  */
 void
-na_pivot_load_items( NAPivot *pivot )
+fma_pivot_load_items( FMAPivot *pivot )
 {
-       static const gchar *thisfn = "na_pivot_load_items";
+       static const gchar *thisfn = "fma_pivot_load_items";
        GSList *messages, *im;
 
-       g_return_if_fail( NA_IS_PIVOT( pivot ));
+       g_return_if_fail( FMA_IS_PIVOT( pivot ));
 
        if( !pivot->private->dispose_has_run ){
 
@@ -581,19 +581,19 @@ na_pivot_load_items( NAPivot *pivot )
 }
 
 /*
- * na_pivot_set_new_items:
- * @pivot: this #NAPivot instance.
+ * fma_pivot_set_new_items:
+ * @pivot: this #FMAPivot instance.
  * @tree: the new tree of items.
  *
  * Replace the current list with this one, acquiring the full ownership
  * of the provided @tree.
  */
 void
-na_pivot_set_new_items( NAPivot *pivot, GList *items )
+fma_pivot_set_new_items( FMAPivot *pivot, GList *items )
 {
-       static const gchar *thisfn = "na_pivot_set_new_items";
+       static const gchar *thisfn = "fma_pivot_set_new_items";
 
-       g_return_if_fail( NA_IS_PIVOT( pivot ));
+       g_return_if_fail( FMA_IS_PIVOT( pivot ));
 
        if( !pivot->private->dispose_has_run ){
 
@@ -606,9 +606,9 @@ na_pivot_set_new_items( NAPivot *pivot, GList *items )
 }
 
 /*
- * na_pivot_on_item_changed_handler:
+ * fma_pivot_on_item_changed_handler:
  * @provider: the #FMAIIOProvider which has emitted the signal.
- * @pivot: this #NAPivot instance.
+ * @pivot: this #FMAPivot instance.
  *
  * This handler is trigerred by #FMAIIOProvider providers when an action
  * is changed in their underlying storage subsystems.
@@ -621,12 +621,12 @@ na_pivot_set_new_items( NAPivot *pivot, GList *items )
  * serie, and then signal our consumers.
  */
 void
-na_pivot_on_item_changed_handler( FMAIIOProvider *provider, NAPivot *pivot  )
+fma_pivot_on_item_changed_handler( FMAIIOProvider *provider, FMAPivot *pivot  )
 {
-       static const gchar *thisfn = "na_pivot_on_item_changed_handler";
+       static const gchar *thisfn = "fma_pivot_on_item_changed_handler";
 
        g_return_if_fail( FMA_IS_IIO_PROVIDER( provider ));
-       g_return_if_fail( NA_IS_PIVOT( pivot ));
+       g_return_if_fail( FMA_IS_PIVOT( pivot ));
 
        if( !pivot->private->dispose_has_run ){
                g_debug( "%s: provider=%p, pivot=%p", thisfn, ( void * ) provider, ( void * ) pivot );
@@ -639,30 +639,30 @@ na_pivot_on_item_changed_handler( FMAIIOProvider *provider, NAPivot *pivot  )
  * this callback is triggered after having received a first 'item-changed' event,
  * and having received no more event during a 'st_burst_timeout' period; we can
  * so suppose that the burst if modification events is terminated
- * this is up to NAPivot to send now its summarized signal
+ * this is up to FMAPivot to send now its summarized signal
  */
 static void
-on_items_changed_timeout( NAPivot *pivot )
+on_items_changed_timeout( FMAPivot *pivot )
 {
-       static const gchar *thisfn = "na_pivot_on_items_changed_timeout";
+       static const gchar *thisfn = "fma_pivot_on_items_changed_timeout";
 
-       g_return_if_fail( NA_IS_PIVOT( pivot ));
+       g_return_if_fail( FMA_IS_PIVOT( pivot ));
 
        g_debug( "%s: emitting %s signal", thisfn, PIVOT_SIGNAL_ITEMS_CHANGED );
        g_signal_emit_by_name(( gpointer ) pivot, PIVOT_SIGNAL_ITEMS_CHANGED );
 }
 
 /*
- * na_pivot_set_loadable:
- * @pivot: this #NAPivot instance.
+ * fma_pivot_set_loadable:
+ * @pivot: this #FMAPivot instance.
  * @loadable: the population of items to be loaded.
  *
  * Sets the loadable set.
  */
 void
-na_pivot_set_loadable( NAPivot *pivot, guint loadable )
+fma_pivot_set_loadable( FMAPivot *pivot, guint loadable )
 {
-       g_return_if_fail( NA_IS_PIVOT( pivot ));
+       g_return_if_fail( FMA_IS_PIVOT( pivot ));
 
        if( !pivot->private->dispose_has_run ){
 
diff --git a/src/core/na-updater.c b/src/core/na-updater.c
index 779fd5a..8f67210 100644
--- a/src/core/na-updater.c
+++ b/src/core/na-updater.c
@@ -53,7 +53,7 @@ struct _NAUpdaterPrivate {
        gboolean is_level_zero_writable;
 };
 
-static NAPivotClass *st_parent_class = NULL;
+static FMAPivotClass *st_parent_class = NULL;
 
 static GType    register_type( void );
 static void     class_init( NAUpdaterClass *klass );
@@ -97,7 +97,7 @@ register_type( void )
 
        g_debug( "%s", thisfn );
 
-       type = g_type_register_static( NA_TYPE_PIVOT, "NAUpdater", &info, 0 );
+       type = g_type_register_static( FMA_TYPE_PIVOT, "NAUpdater", &info, 0 );
 
        return( type );
 }
@@ -288,7 +288,7 @@ na_updater_check_item_writability_status( const NAUpdater *updater, const FMAObj
                        /* the get_writable_provider() api already takes care of above checks
                         */
                        } else {
-                               provider = fma_io_provider_find_writable_io_provider( NA_PIVOT( updater ));
+                               provider = fma_io_provider_find_writable_io_provider( FMA_PIVOT( updater ));
                                if( !provider ){
                                        writable = FALSE;
                                        reason = FMA_IIO_PROVIDER_STATUS_NO_PROVIDER_FOUND;
@@ -418,7 +418,7 @@ na_updater_insert_item( NAUpdater *updater, FMAObjectItem *item, const gchar *pa
                g_object_get( G_OBJECT( updater ), PIVOT_PROP_TREE, &tree, NULL );
 
                if( parent_id ){
-                       parent = na_pivot_get_item( NA_PIVOT( updater ), parent_id );
+                       parent = fma_pivot_get_item( FMA_PIVOT( updater ), parent_id );
                }
 
                if( parent ){
@@ -433,7 +433,7 @@ na_updater_insert_item( NAUpdater *updater, FMAObjectItem *item, const gchar *pa
 
 /*
  * na_updater_remove_item:
- * @updater: this #NAPivot instance.
+ * @updater: this #FMAPivot instance.
  * @item: the #FMAObjectItem to be removed from the list.
  *
  * Removes a #FMAObjectItem from the hierarchical tree. Does not delete it.
@@ -444,7 +444,7 @@ na_updater_remove_item( NAUpdater *updater, FMAObject *item )
        GList *tree;
        FMAObjectItem *parent;
 
-       g_return_if_fail( NA_IS_PIVOT( updater ));
+       g_return_if_fail( FMA_IS_PIVOT( updater ));
 
        if( !updater->private->dispose_has_run ){
 
@@ -521,8 +521,8 @@ na_updater_load_items( NAUpdater *updater )
        if( !updater->private->dispose_has_run ){
                g_debug( "%s: updater=%p (%s)", thisfn, ( void * ) updater, G_OBJECT_TYPE_NAME( updater ));
 
-               na_pivot_load_items( NA_PIVOT( updater ));
-               tree = na_pivot_get_items( NA_PIVOT( updater ));
+               fma_pivot_load_items( FMA_PIVOT( updater ));
+               tree = fma_pivot_get_items( FMA_PIVOT( updater ));
                g_list_foreach( tree, ( GFunc ) set_writability_status, ( gpointer ) updater );
        }
 
@@ -569,7 +569,7 @@ na_updater_write_item( const NAUpdater *updater, FMAObjectItem *item, GSList **m
                FMAIOProvider *provider = fma_object_get_provider( item );
 
                if( !provider ){
-                       provider = fma_io_provider_find_writable_io_provider( NA_PIVOT( updater ));
+                       provider = fma_io_provider_find_writable_io_provider( FMA_PIVOT( updater ));
                        g_return_val_if_fail( provider, FMA_IIO_PROVIDER_STATUS_NO_PROVIDER_FOUND );
                }
 
diff --git a/src/io-desktop/nadp-monitor.h b/src/io-desktop/nadp-monitor.h
index 1bbdaed..67cabc2 100644
--- a/src/io-desktop/nadp-monitor.h
+++ b/src/io-desktop/nadp-monitor.h
@@ -43,7 +43,7 @@
  * file monitor would be triggered without the parent directory monitor
  * has been itself triggered. We, so only monitor directories (not files).
  * More, as several events may be triggered for one user modification,
- * we try to factorize all monitor events before advertizing NAPivot.
+ * we try to factorize all monitor events before advertizing FMAPivot.
  */
 
 #include "nadp-desktop-provider.h"
diff --git a/src/nact/main.c b/src/nact/main.c
index a755ef0..8ebca14 100644
--- a/src/nact/main.c
+++ b/src/nact/main.c
@@ -60,7 +60,7 @@ main( int argc, char *argv[] )
 
        /* pwi 2011-01-05
         * run GConf migration tools before doing anything else
-        * above all before allocating a new NAPivot
+        * above all before allocating a new FMAPivot
         */
        fma_gconf_migration_run();
 
diff --git a/src/nact/nact-application.c b/src/nact/nact-application.c
index 36115ff..26de77d 100644
--- a/src/nact/nact-application.c
+++ b/src/nact/nact-application.c
@@ -417,11 +417,11 @@ application_startup( GApplication *application )
                G_APPLICATION_CLASS( st_parent_class )->startup( application );
        }
 
-       /* create the NAPivot object (loading the plugins and so on)
+       /* create the FMAPivot object (loading the plugins and so on)
         * after having dealt with command-line arguments
         */
        priv->updater = na_updater_new();
-       na_pivot_set_loadable( NA_PIVOT( priv->updater ), PIVOT_LOAD_ALL );
+       fma_pivot_set_loadable( FMA_PIVOT( priv->updater ), PIVOT_LOAD_ALL );
 
        /* define the application menu */
        nact_menu_app( NACT_APPLICATION( application ));
diff --git a/src/nact/nact-assistant-export.c b/src/nact/nact-assistant-export.c
index 9d6e02c..1a9c003 100644
--- a/src/nact/nact-assistant-export.c
+++ b/src/nact/nact-assistant-export.c
@@ -209,7 +209,7 @@ ioptions_list_get_formats( const FMAIOptionsList *instance, GtkWidget *container
 
        application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
        updater = nact_application_get_updater( application );
-       formats = fma_exporter_get_formats( NA_PIVOT( updater ));
+       formats = fma_exporter_get_formats( FMA_PIVOT( updater ));
 
        return( formats );
 }
@@ -789,7 +789,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
                }
 
                if( strcmp( str->format, EXPORTER_FORMAT_NOEXPORT ) != 0 ){
-                       str->fname = fma_exporter_to_file( NA_PIVOT( updater ), str->item, 
window->private->uri, str->format, &str->msg );
+                       str->fname = fma_exporter_to_file( FMA_PIVOT( updater ), str->item, 
window->private->uri, str->format, &str->msg );
                }
 
                g_free( str->format );
diff --git a/src/nact/nact-assistant-import.c b/src/nact/nact-assistant-import.c
index ac493d3..2f8101a 100644
--- a/src/nact/nact-assistant-import.c
+++ b/src/nact/nact-assistant-import.c
@@ -667,7 +667,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
        importer_parms.preferred_mode = fma_import_mode_get_id( FMA_IMPORT_MODE( window->private->mode ));
        importer_parms.parent_toplevel = base_window_get_gtk_toplevel( BASE_WINDOW( wnd ));
 
-       import_results = fma_importer_import_from_uris( NA_PIVOT( updater ), &importer_parms );
+       import_results = fma_importer_import_from_uris( FMA_PIVOT( updater ), &importer_parms );
 
        insertable_items = NULL;
        overriden_items = NULL;
diff --git a/src/nact/nact-clipboard.c b/src/nact/nact-clipboard.c
index b5a9563..70676c7 100644
--- a/src/nact/nact-clipboard.c
+++ b/src/nact/nact-clipboard.c
@@ -627,11 +627,11 @@ export_row_object( NactClipboard *clipboard, FMAObject *object, const gchar *des
 
                if( strcmp( format, EXPORTER_FORMAT_NOEXPORT ) != 0 ){
                        if( dest_folder ){
-                               fname = fma_exporter_to_file( NA_PIVOT( updater ), item, dest_folder, format, 
&msgs );
+                               fname = fma_exporter_to_file( FMA_PIVOT( updater ), item, dest_folder, 
format, &msgs );
                                g_free( fname );
 
                        } else {
-                               buffer = fma_exporter_to_buffer( NA_PIVOT( updater ), item, format, &msgs );
+                               buffer = fma_exporter_to_buffer( FMA_PIVOT( updater ), item, format, &msgs );
                                if( buffer && strlen( buffer )){
                                        data = g_string_append( data, buffer );
                                        g_free( buffer );
diff --git a/src/nact/nact-export-ask.c b/src/nact/nact-export-ask.c
index 666abc0..382cc00 100644
--- a/src/nact/nact-export-ask.c
+++ b/src/nact/nact-export-ask.c
@@ -165,7 +165,7 @@ ioptions_list_get_formats( const FMAIOptionsList *instance, GtkWidget *container
 
        application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
        updater = nact_application_get_updater( application );
-       formats = fma_exporter_get_formats( NA_PIVOT( updater ));
+       formats = fma_exporter_get_formats( FMA_PIVOT( updater ));
 
        return( formats );
 }
diff --git a/src/nact/nact-main-window.c b/src/nact/nact-main-window.c
index 1aef497..e6196b9 100644
--- a/src/nact/nact-main-window.c
+++ b/src/nact/nact-main-window.c
@@ -40,7 +40,7 @@
 #include "core/fma-about.h"
 #include "core/fma-gtk-utils.h"
 #include "core/fma-iprefs.h"
-#include "core/na-pivot.h"
+#include "core/fma-pivot.h"
 
 #include "nact-iaction-tab.h"
 #include "nact-icommand-tab.h"
@@ -1112,7 +1112,7 @@ setup_writability_status( NactMainWindow *window )
 }
 
 /*
- * The handler of the signal sent by NAPivot when items have been modified
+ * The handler of the signal sent by FMAPivot when items have been modified
  * in the underlying storage subsystems
  */
 static void
diff --git a/src/nact/nact-menu-file.c b/src/nact/nact-menu-file.c
index b8d866a..0b212d8 100644
--- a/src/nact/nact-menu-file.c
+++ b/src/nact/nact-menu-file.c
@@ -309,7 +309,7 @@ nact_menu_file_save_items( NactMainWindow *window )
                messages = NULL;
        }
 
-       na_pivot_set_new_items( NA_PIVOT( sdata->updater ), g_list_reverse( new_pivot ));
+       fma_pivot_set_new_items( FMA_PIVOT( sdata->updater ), g_list_reverse( new_pivot ));
        fma_object_free_items( items );
        nact_main_window_block_reload( window );
        g_signal_emit_by_name( items_view, TREE_SIGNAL_MODIFIED_STATUS_CHANGED, FALSE );
diff --git a/src/nact/nact-menu.c b/src/nact/nact-menu.c
index 5bea97e..71f51e8 100644
--- a/src/nact/nact-menu.c
+++ b/src/nact/nact-menu.c
@@ -326,7 +326,7 @@ nact_menu_win( NactMainWindow *main_window )
        sdata->updater = nact_application_get_updater( NACT_APPLICATION( application ));
        sdata->is_level_zero_writable = na_updater_is_level_zero_writable( sdata->updater );
        sdata->has_writable_providers =
-                       ( fma_io_provider_find_writable_io_provider( NA_PIVOT( sdata->updater )) != NULL );
+                       ( fma_io_provider_find_writable_io_provider( FMA_PIVOT( sdata->updater )) != NULL );
 
        g_debug( "%s: na_updater_is_level_zero_writable=%s, fma_io_provider_find_writable_io_provider=%s",
                        thisfn,
diff --git a/src/nact/nact-preferences-editor.c b/src/nact/nact-preferences-editor.c
index b37b095..4edf481 100644
--- a/src/nact/nact-preferences-editor.c
+++ b/src/nact/nact-preferences-editor.c
@@ -268,7 +268,7 @@ ioptions_list_get_options( const FMAIOptionsList *instance, GtkWidget *container
        if( container == base_window_get_widget( BASE_WINDOW( instance ), "PreferencesExportFormatVBox" )){
                application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( instance )));
                updater = nact_application_get_updater( application );
-               options = fma_exporter_get_formats( NA_PIVOT( updater ));
+               options = fma_exporter_get_formats( FMA_PIVOT( updater ));
 
        } else if( container == base_window_get_widget( BASE_WINDOW( instance ), "PreferencesImportModeVBox" 
)){
                options = fma_importer_get_modes();
diff --git a/src/nact/nact-providers-list.c b/src/nact/nact-providers-list.c
index 794974a..7ec6c45 100644
--- a/src/nact/nact-providers-list.c
+++ b/src/nact/nact-providers-list.c
@@ -239,14 +239,14 @@ init_view_setup_providers( GtkTreeView *treeview, BaseWindow *window )
 
        application = NACT_APPLICATION( base_window_get_application( window ));
        updater = nact_application_get_updater( application );
-       providers = fma_io_provider_get_io_providers_list( NA_PIVOT( updater ));
+       providers = fma_io_provider_get_io_providers_list( FMA_PIVOT( updater ));
 
        for( iter = providers ; iter ; iter = iter->next ){
                provider = FMA_IO_PROVIDER( iter->data );
                id = fma_io_provider_get_id( provider );
                libelle = fma_io_provider_get_name( provider );
-               readable = fma_io_provider_is_conf_readable( provider, NA_PIVOT( updater ), 
&readable_mandatory );
-               writable = fma_io_provider_is_conf_writable( provider, NA_PIVOT( updater ), 
&writable_mandatory );
+               readable = fma_io_provider_is_conf_readable( provider, FMA_PIVOT( updater ), 
&readable_mandatory );
+               writable = fma_io_provider_is_conf_writable( provider, FMA_PIVOT( updater ), 
&writable_mandatory );
 
                g_debug( "%s: id=%s, readable=%s (mandatory=%s), writable=%s (mandatory=%s)",
                                thisfn, id,
diff --git a/src/nact/nact-tree-ieditable.c b/src/nact/nact-tree-ieditable.c
index 10c042f..2715e22 100644
--- a/src/nact/nact-tree-ieditable.c
+++ b/src/nact/nact-tree-ieditable.c
@@ -1037,7 +1037,7 @@ check_level_zero_status( NactTreeIEditable *instance )
        gchar *pivot_str, *view_str;
 
        ied = get_instance_data( instance );
-       items = na_pivot_get_items( NA_PIVOT( ied->updater ));
+       items = fma_pivot_get_items( FMA_PIVOT( ied->updater ));
        pivot_str = get_items_id_list_str( items );
 
        items = nact_tree_view_get_items( NACT_TREE_VIEW( instance ));
diff --git a/src/nact/nact-tree-model-dnd.c b/src/nact/nact-tree-model-dnd.c
index a2a5b7f..039bd70 100644
--- a/src/nact/nact-tree-model-dnd.c
+++ b/src/nact/nact-tree-model-dnd.c
@@ -909,7 +909,7 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
        parms.preferred_mode = 0;
        parms.parent_toplevel = GTK_WINDOW( main_window );
 
-       import_results = fma_importer_import_from_uris( NA_PIVOT( updater ), &parms );
+       import_results = fma_importer_import_from_uris( FMA_PIVOT( updater ), &parms );
 
        /* analysing output results, simultaneously building a concatenation
         * of all lines of messages, and the list of imported items
diff --git a/src/nact/nact-tree-model.c b/src/nact/nact-tree-model.c
index a57da0f..3517f9f 100644
--- a/src/nact/nact-tree-model.c
+++ b/src/nact/nact-tree-model.c
@@ -649,12 +649,12 @@ nact_tree_model_delete( NactTreeModel *model, FMAObject *object )
  * nact_tree_model_fill:
  * @model: this #NactTreeModel instance.
  * @ŧreeview: the #GtkTreeView widget.
- * @items: this list of items, usually from #NAPivot, which will be used
+ * @items: this list of items, usually from #FMAPivot, which will be used
  *  to fill up the tree store.
  *
  * Fill up the tree store with specified items.
  *
- * We enter with the GSList owned by NAPivot which contains the ordered
+ * We enter with the GSList owned by FMAPivot which contains the ordered
  * list of level-zero items. We want have a duplicate of this list in
  * tree store, so that we are able to freely edit it.
  */
diff --git a/src/plugin-menu/nautilus-module.c b/src/plugin-menu/nautilus-module.c
index 6f929d4..c403b77 100644
--- a/src/plugin-menu/nautilus-module.c
+++ b/src/plugin-menu/nautilus-module.c
@@ -74,7 +74,7 @@ nautilus_module_initialize( GTypeModule *module )
 
        /* pwi 2011-01-05
         * run GConf migration tools before doing anything else
-        * above all before allocating a new NAPivot
+        * above all before allocating a new FMAPivot
         */
        fma_gconf_migration_run();
 
diff --git a/src/test/test-reader.c b/src/test/test-reader.c
index 892f804..61420c4 100755
--- a/src/test/test-reader.c
+++ b/src/test/test-reader.c
@@ -36,7 +36,7 @@
 
 #include <api/fma-core-utils.h>
 
-#include <core/na-pivot.h>
+#include <core/fma-pivot.h>
 #include <core/fma-importer.h>
 
 static gchar     *uri     = "";
@@ -74,9 +74,9 @@ main( int argc, char **argv )
        GOptionContext *context = init_options();
        check_options( argc, argv, context );
 
-       NAPivot *pivot = na_pivot_new();
-       na_pivot_set_loadable( pivot, !PIVOT_LOAD_DISABLED & !PIVOT_LOAD_INVALID );
-       na_pivot_load_items( pivot );
+       FMAPivot *pivot = fma_pivot_new();
+       fma_pivot_set_loadable( pivot, !PIVOT_LOAD_DISABLED & !PIVOT_LOAD_INVALID );
+       fma_pivot_load_items( pivot );
 
        parms.uris = g_slist_prepend( NULL, uri );
        parms.check_fn = NULL;
diff --git a/src/utils/nautilus-actions-new.c b/src/utils/nautilus-actions-new.c
index 4eec5c1..e852b4b 100644
--- a/src/utils/nautilus-actions-new.c
+++ b/src/utils/nautilus-actions-new.c
@@ -189,7 +189,7 @@ main( int argc, char** argv )
 
        /* pwi 2011-01-05
         * run GConf migration tools before doing anything else
-        * above all before allocating a new NAPivot
+        * above all before allocating a new FMAPivot
         */
        fma_gconf_migration_run();
 
@@ -583,7 +583,7 @@ output_to_desktop( FMAObjectAction *action, GSList **msgs )
        gboolean code;
 
        updater = na_updater_new();
-       provider = fma_io_provider_find_io_provider_by_id( NA_PIVOT( updater ), "na-desktop" );
+       provider = fma_io_provider_find_io_provider_by_id( FMA_PIVOT( updater ), "na-desktop" );
 
        if( provider ){
                fma_object_set_provider( action, provider );
@@ -609,7 +609,7 @@ output_to_stdout( const FMAObjectAction *action, GSList **msgs )
        gchar *buffer;
 
        updater = na_updater_new();
-       buffer = fma_exporter_to_buffer( NA_PIVOT( updater ), FMA_OBJECT_ITEM( action ), "Desktop1", msgs );
+       buffer = fma_exporter_to_buffer( FMA_PIVOT( updater ), FMA_OBJECT_ITEM( action ), "Desktop1", msgs );
        ret = ( buffer != NULL );
 
        if( buffer ){
diff --git a/src/utils/nautilus-actions-print.c b/src/utils/nautilus-actions-print.c
index 80ec61b..a11a4b6 100644
--- a/src/utils/nautilus-actions-print.c
+++ b/src/utils/nautilus-actions-print.c
@@ -71,7 +71,7 @@ static GOptionEntry misc_entries[] = {
        { NULL }
 };
 
-static NAPivot *pivot = NULL;
+static FMAPivot *pivot = NULL;
 
 static GOptionContext  *init_options( void );
 static FMAObjectItem    *get_item( const gchar *id );
@@ -196,11 +196,11 @@ get_item( const gchar *id )
 {
        FMAObjectItem *item = NULL;
 
-       pivot = na_pivot_new();
-       na_pivot_set_loadable( pivot, PIVOT_LOAD_ALL );
-       na_pivot_load_items( pivot );
+       pivot = fma_pivot_new();
+       fma_pivot_set_loadable( pivot, PIVOT_LOAD_ALL );
+       fma_pivot_load_items( pivot );
 
-       item = na_pivot_get_item( pivot, id );
+       item = fma_pivot_get_item( pivot, id );
 
        if( !item ){
                g_printerr( _( "Error: item '%s' doesn't exist.\n" ), id );
diff --git a/src/core/fma-exporter.c b/src/core/fma-exporter.c
index cd9cb38..b10d056 100644
--- a/src/core/fma-exporter.c
+++ b/src/core/fma-exporter.c
@@ -66,7 +66,7 @@ static void   on_pixbuf_finalized( gpointer user_data, GObject *pixbuf );
 
 /*
  * fma_exporter_get_formats:
- * @pivot: the #NAPivot instance.
+ * @pivot: the #FMAPivot instance.
  *
  * Returns: a list of #FMAExportFormat objects, each of them addressing an
  * available export format, i.e. a format provided by a module which
@@ -75,17 +75,17 @@ static void   on_pixbuf_finalized( gpointer user_data, GObject *pixbuf );
  * The returned list should later be fma_exporter_free_formats() by the caller.
  */
 GList *
-fma_exporter_get_formats( const NAPivot *pivot )
+fma_exporter_get_formats( const FMAPivot *pivot )
 {
        GList *iexporters, *imod;
        GList *formats;
        GList *str_list, *is;
        FMAExportFormat *format;
 
-       g_return_val_if_fail( NA_IS_PIVOT( pivot ), NULL );
+       g_return_val_if_fail( FMA_IS_PIVOT( pivot ), NULL );
 
        formats = NULL;
-       iexporters = na_pivot_get_providers( pivot, FMA_TYPE_IEXPORTER );
+       iexporters = fma_pivot_get_providers( pivot, FMA_TYPE_IEXPORTER );
 
        for( imod = iexporters ; imod ; imod = imod->next ){
                str_list = exporter_get_formats( FMA_IEXPORTER( imod->data ));
@@ -98,7 +98,7 @@ fma_exporter_get_formats( const NAPivot *pivot )
                exporter_free_formats( FMA_IEXPORTER( imod->data ), str_list );
        }
 
-       na_pivot_free_providers( iexporters );
+       fma_pivot_free_providers( iexporters );
 
        return( formats );
 }
@@ -247,7 +247,7 @@ on_pixbuf_finalized( gpointer user_data /* ==NULL */, GObject *pixbuf )
 
 /*
  * fma_exporter_to_buffer:
  * @pivot: the #NAPivot pivot for the running application.
  * @item: a #FMAObjectItem-derived object.
  * @format: the target format identifier.
  * @messages: a pointer to a #GSList list of strings; the provider
@@ -259,7 +259,7 @@ on_pixbuf_finalized( gpointer user_data /* ==NULL */, GObject *pixbuf )
  * be g_free() by the caller, or %NULL if an error has been detected.
  */
 gchar *
-fma_exporter_to_buffer( const NAPivot *pivot,
+fma_exporter_to_buffer( const FMAPivot *pivot,
                const FMAObjectItem *item, const gchar *format, GSList **messages )
 {
        static const gchar *thisfn = "fma_exporter_to_buffer";
@@ -269,7 +269,7 @@ fma_exporter_to_buffer( const NAPivot *pivot,
        gchar *name;
        gchar *msg;
 
-       g_return_val_if_fail( NA_IS_PIVOT( pivot ), NULL );
+       g_return_val_if_fail( FMA_IS_PIVOT( pivot ), NULL );
        g_return_val_if_fail( FMA_IS_OBJECT_ITEM( item ), NULL );
 
        buffer = NULL;
@@ -318,7 +318,7 @@ fma_exporter_to_buffer( const NAPivot *pivot,
 
 /*
  * fma_exporter_to_file:
  * @pivot: the #NAPivot pivot for the running application.
  * @item: a #FMAObjectItem-derived object.
  * @folder_uri: the URI of the target folder.
  * @format: the target format identifier.
@@ -331,7 +331,7 @@ fma_exporter_to_buffer( const NAPivot *pivot,
  * should be g_free() by the caller, or %NULL if an error has been detected.
  */
 gchar *
-fma_exporter_to_file( const NAPivot *pivot,
+fma_exporter_to_file( const FMAPivot *pivot,
                const FMAObjectItem *item, const gchar *folder_uri, const gchar *format, GSList **messages )
 {
        static const gchar *thisfn = "fma_exporter_to_file";
@@ -341,7 +341,7 @@ fma_exporter_to_file( const NAPivot *pivot,
        gchar *msg;
        gchar *name;
 
-       g_return_val_if_fail( NA_IS_PIVOT( pivot ), NULL );
+       g_return_val_if_fail( FMA_IS_PIVOT( pivot ), NULL );
        g_return_val_if_fail( FMA_IS_OBJECT_ITEM( item ), NULL );
 
        export_uri = NULL;
@@ -405,7 +405,7 @@ exporter_get_name( const FMAIExporter *exporter )
 
 /**
  * fma_exporter_find_for_format:
- * @pivot: the #NAPivot instance.
+ * @pivot: the #FMAPivot instance.
  * @format: the string identifier of the searched format.
  *
  * Returns: the #FMAIExporter instance which provides the @format export
@@ -413,14 +413,14 @@ exporter_get_name( const FMAIExporter *exporter )
  * released by the caller.
  */
 FMAIExporter *
-fma_exporter_find_for_format( const NAPivot *pivot, const gchar *format )
+fma_exporter_find_for_format( const FMAPivot *pivot, const gchar *format )
 {
        FMAIExporter *exporter;
        GList *formats, *ifmt;
        gchar *id;
        FMAExportFormat *export_format;
 
-       g_return_val_if_fail( NA_IS_PIVOT( pivot ), NULL );
+       g_return_val_if_fail( FMA_IS_PIVOT( pivot ), NULL );
 
        exporter = NULL;
        formats = fma_exporter_get_formats( pivot );
@@ -247,7 +247,7 @@ on_pixbuf_finalized( gpointer user_data /* ==NULL */, GObject *pixbuf )
 /*
  * fma_exporter_to_buffer:
- * @pivot: the #NAPivot pivot for the running application.
+ * @pivot: the #FMAPivot pivot for the running application.
  * @item: a #FMAObjectItem-derived object.
  * @format: the target format identifier.
@@ -318,7 +318,7 @@ fma_exporter_to_buffer( const NAPivot *pivot,
 /*
  * fma_exporter_to_file:
- * @pivot: the #NAPivot pivot for the running application.
+ * @pivot: the #FMAPivot pivot for the running application.
  * @item: a #FMAObjectItem-derived object.
  * @folder_uri: the URI of the target folder.
diff --git a/src/core/fma-importer.c b/src/core/fma-importer.c
index bbd755f..c1a5421 100644
--- a/src/core/fma-importer.c
+++ b/src/core/fma-importer.c
@@ -89,7 +89,7 @@ static FMAImportModeStr st_import_ask_mode = {
                        "import-mode-ask.png"
 };
 
-static FMAImporterResult *import_from_uri( const NAPivot *pivot, GList *modules, const gchar *uri );
+static FMAImporterResult *import_from_uri( const FMAPivot *pivot, GList *modules, const gchar *uri );
 static void              manage_import_mode( FMAImporterParms *parms, GList *results, 
FMAImporterAskUserParms *ask_parms, FMAImporterResult *result );
 static FMAObjectItem     *is_importing_already_exists( FMAImporterParms *parms, GList *results, 
FMAImporterResult *result );
 static void              renumber_label_item( FMAObjectItem *item );
@@ -102,7 +102,7 @@ static FMAIOption        *get_mode_from_struct( const FMAImportModeStr *str );
 
 /*
  * fma_importer_import_from_uris:
  * @pivot: the #NAPivot pivot for this application.
  * @parms: a #FMAImporterParms structure.
  *
  * Imports a list of URIs.
@@ -126,7 +126,7 @@ static FMAIOption        *get_mode_from_struct( const FMAImportModeStr *str );
  * Since: 2.30
  */
 GList *
-fma_importer_import_from_uris( const NAPivot *pivot, FMAImporterParms *parms )
+fma_importer_import_from_uris( const FMAPivot *pivot, FMAImporterParms *parms )
 {
        static const gchar *thisfn = "fma_importer_import_from_uris";
        GList *results, *ires;
@@ -136,7 +136,7 @@ fma_importer_import_from_uris( const NAPivot *pivot, FMAImporterParms *parms )
        FMAImporterAskUserParms ask_parms;
        gchar *mode_str;
 
-       g_return_val_if_fail( NA_IS_PIVOT( pivot ), NULL );
+       g_return_val_if_fail( FMA_IS_PIVOT( pivot ), NULL );
        g_return_val_if_fail( parms != NULL, NULL );
 
        results = NULL;
@@ -145,14 +145,14 @@ fma_importer_import_from_uris( const NAPivot *pivot, FMAImporterParms *parms )
 
        /* first phase: just try to import the uris into memory
         */
-       modules = na_pivot_get_providers( pivot, FMA_TYPE_IIMPORTER );
+       modules = fma_pivot_get_providers( pivot, FMA_TYPE_IIMPORTER );
 
        for( uri = parms->uris ; uri ; uri = uri->next ){
                import_result = import_from_uri( pivot, modules, ( const gchar * ) uri->data );
                results = g_list_prepend( results, import_result );
        }
 
-       na_pivot_free_providers( modules );
+       fma_pivot_free_providers( modules );
 
        results = g_list_reverse( results );
 
@@ -213,7 +213,7 @@ fma_importer_free_result( FMAImporterResult *result )
  * imported the item.
  */
 static FMAImporterResult *
-import_from_uri( const NAPivot *pivot, GList *modules, const gchar *uri )
+import_from_uri( const FMAPivot *pivot, GList *modules, const gchar *uri )
 {
        FMAImporterResult *result;
        FMAIImporterImportFromUriParmsv2 provider_parms;
@@ -102,7 +102,7 @@ static FMAIOption        *get_mode_from_struct( const FMAImportModeStr *str );
 /*
  * fma_importer_import_from_uris:
- * @pivot: the #NAPivot pivot for this application.
+ * @pivot: the #FMAPivot pivot for this application.
  * @parms: a #FMAImporterParms structure.
  *
diff --git a/src/core/fma-io-provider.c b/src/core/fma-io-provider.c
index 09838d9..64f4f5c 100644
--- a/src/core/fma-io-provider.c
+++ b/src/core/fma-io-provider.c
@@ -85,20 +85,20 @@ static void          instance_finalize( GObject *object );
 static void          dump( const FMAIOProvider *provider );
 static void          dump_providers_list( GList *providers );
 #endif
-static FMAIOProvider *io_provider_new( const NAPivot *pivot, FMAIIOProvider *module, const gchar *id );
-static GList        *io_providers_list_add_from_plugins( const NAPivot *pivot, GList *list );
-static GList        *io_providers_list_add_from_prefs( const NAPivot *pivot, GList *objects_list );
+static FMAIOProvider *io_provider_new( const FMAPivot *pivot, FMAIIOProvider *module, const gchar *id );
+static GList        *io_providers_list_add_from_plugins( const FMAPivot *pivot, GList *list );
+static GList        *io_providers_list_add_from_prefs( const FMAPivot *pivot, GList *objects_list );
 static GSList       *io_providers_get_from_prefs( void );
-static GList        *io_providers_list_add_from_write_order( const NAPivot *pivot, GList *objects_list );
-static GList        *io_providers_list_append_object( const NAPivot *pivot, GList *list, FMAIIOProvider 
*module, const gchar *id );
-static void          io_providers_list_set_module( const NAPivot *pivot, FMAIOProvider *provider_object, 
FMAIIOProvider *provider_module );
-static gboolean      is_conf_writable( const FMAIOProvider *provider, const NAPivot *pivot, gboolean 
*mandatory );
-static gboolean      is_finally_writable( const FMAIOProvider *provider, const NAPivot *pivot, guint *reason 
);
-static GList        *load_items_filter_unwanted_items( const NAPivot *pivot, GList *merged, guint 
loadable_set );
+static GList        *io_providers_list_add_from_write_order( const FMAPivot *pivot, GList *objects_list );
+static GList        *io_providers_list_append_object( const FMAPivot *pivot, GList *list, FMAIIOProvider 
*module, const gchar *id );
+static void          io_providers_list_set_module( const FMAPivot *pivot, FMAIOProvider *provider_object, 
FMAIIOProvider *provider_module );
+static gboolean      is_conf_writable( const FMAIOProvider *provider, const FMAPivot *pivot, gboolean 
*mandatory );
+static gboolean      is_finally_writable( const FMAIOProvider *provider, const FMAPivot *pivot, guint 
*reason );
+static GList        *load_items_filter_unwanted_items( const FMAPivot *pivot, GList *merged, guint 
loadable_set );
 static GList        *load_items_filter_unwanted_items_rec( GList *merged, guint loadable_set );
-static GList        *load_items_get_merged_list( const NAPivot *pivot, guint loadable_set, GSList **messages 
);
+static GList        *load_items_get_merged_list( const FMAPivot *pivot, guint loadable_set, GSList 
**messages );
 static GList        *load_items_hierarchy_build( GList **tree, GSList *level_zero, gboolean list_if_empty, 
FMAObjectItem *parent );
-static GList        *load_items_hierarchy_sort( const NAPivot *pivot, GList *tree, GCompareFunc fn );
+static GList        *load_items_hierarchy_sort( const FMAPivot *pivot, GList *tree, GCompareFunc fn );
 static gint          peek_item_by_id_compare( const FMAObject *obj, const gchar *id );
 static FMAIOProvider *peek_provider_by_id( const GList *providers, const gchar *id );
 
@@ -309,7 +309,7 @@ instance_finalize( GObject *object )
 
 /*
  * fma_io_provider_find_writable_io_provider:
- * @pivot: the #NAPivot instance.
+ * @pivot: the #FMAPivot instance.
  *
  * Returns: the first willing and able to write I/O provider, or NULL.
  *
@@ -317,7 +317,7 @@ instance_finalize( GObject *object )
  * be released by the caller.
  */
 FMAIOProvider *
-fma_io_provider_find_writable_io_provider( const NAPivot *pivot )
+fma_io_provider_find_writable_io_provider( const FMAPivot *pivot )
 {
        const GList *providers;
        const GList *ip;
@@ -337,7 +337,7 @@ fma_io_provider_find_writable_io_provider( const NAPivot *pivot )
 
 /*
  * fma_io_provider_find_io_provider_by_id:
- * @pivot: the #NAPivot instance.
+ * @pivot: the #FMAPivot instance.
  * @id: the identifier of the searched I/O provider.
  *
  * Returns: the I/O provider, or NULL.
@@ -346,7 +346,7 @@ fma_io_provider_find_writable_io_provider( const NAPivot *pivot )
  * be released by the caller.
  */
 FMAIOProvider *
-fma_io_provider_find_io_provider_by_id( const NAPivot *pivot, const gchar *id )
+fma_io_provider_find_io_provider_by_id( const FMAPivot *pivot, const gchar *id )
 {
        const GList *providers;
        const GList *ip;
@@ -368,7 +368,7 @@ fma_io_provider_find_io_provider_by_id( const NAPivot *pivot, const gchar *id )
 
 /*
  * fma_io_provider_get_io_providers_list:
  * @pivot: the current #NAPivot instance.
  *
  * Build (if not already done) the write-ordered list of currently
  * available FMAIOProvider objects.
@@ -389,9 +389,9 @@ fma_io_provider_find_io_provider_by_id( const NAPivot *pivot, const gchar *id )
  * released by the caller.
  */
 const GList *
-fma_io_provider_get_io_providers_list( const NAPivot *pivot )
+fma_io_provider_get_io_providers_list( const FMAPivot *pivot )
 {
-       g_return_val_if_fail( NA_IS_PIVOT( pivot ), NULL );
+       g_return_val_if_fail( FMA_IS_PIVOT( pivot ), NULL );
 
        if( !st_io_providers ){
                st_io_providers = io_providers_list_add_from_write_order( pivot, NULL );
@@ -407,7 +407,7 @@ fma_io_provider_get_io_providers_list( const NAPivot *pivot )
  * without having any pointer to the underlying FMAIIOProvider (if it exists)
  */
 static GList *
-io_providers_list_add_from_write_order( const NAPivot *pivot, GList *objects_list )
+io_providers_list_add_from_write_order( const FMAPivot *pivot, GList *objects_list )
 {
        GList *merged;
        GSList *io_providers, *it;
@@ -431,7 +431,7 @@ io_providers_list_add_from_write_order( const NAPivot *pivot, GList *objects_lis
  * to implement the FMAIIOProvider interface
  */
 static GList *
-io_providers_list_add_from_plugins( const NAPivot *pivot, GList *objects_list )
+io_providers_list_add_from_plugins( const FMAPivot *pivot, GList *objects_list )
 {
        static const gchar *thisfn = "fma_io_provider_io_providers_list_add_from_plugins";
        GList *merged;
@@ -440,7 +440,7 @@ io_providers_list_add_from_plugins( const NAPivot *pivot, GList *objects_list )
        FMAIIOProvider *provider_module;
 
        merged = objects_list;
-       modules_list = na_pivot_get_providers( pivot, FMA_TYPE_IIO_PROVIDER );
+       modules_list = fma_pivot_get_providers( pivot, FMA_TYPE_IIO_PROVIDER );
 
        for( im = modules_list ; im ; im = im->next ){
 
@@ -464,7 +464,7 @@ io_providers_list_add_from_plugins( const NAPivot *pivot, GList *objects_list )
                }
        }
 
-       na_pivot_free_providers( modules_list );
+       fma_pivot_free_providers( modules_list );
 
        return( merged );
 }
@@ -476,7 +476,7 @@ io_providers_list_add_from_plugins( const NAPivot *pivot, GList *objects_list )
  * preferences come from the io-providers status.
  */
 static GList *
-io_providers_list_add_from_prefs( const NAPivot *pivot, GList *objects_list )
+io_providers_list_add_from_prefs( const FMAPivot *pivot, GList *objects_list )
 {
        GList *merged;
        const gchar *id;
@@ -543,7 +543,7 @@ io_providers_get_from_prefs( void )
  * if it does not have been already registered
  */
 static GList *
-io_providers_list_append_object( const NAPivot *pivot, GList *list, FMAIIOProvider *module, const gchar *id )
+io_providers_list_append_object( const FMAPivot *pivot, GList *list, FMAIIOProvider *module, const gchar *id 
)
 {
        GList *merged;
        FMAIOProvider *object;
@@ -584,7 +584,7 @@ peek_provider_by_id( const GList *providers, const gchar *id )
  * module may be NULL
  */
 static FMAIOProvider *
-io_provider_new( const NAPivot *pivot, FMAIIOProvider *module, const gchar *id )
+io_provider_new( const FMAPivot *pivot, FMAIIOProvider *module, const gchar *id )
 {
        FMAIOProvider *object;
 
@@ -601,17 +601,17 @@ io_provider_new( const NAPivot *pivot, FMAIIOProvider *module, const gchar *id )
 
 /*
  * when a IIOProvider plugin is associated with the FMAIOProvider object,
  * we connect the NAPivot callback to the 'item-changed' signal
  */
 static void
-io_providers_list_set_module( const NAPivot *pivot, FMAIOProvider *provider_object, FMAIIOProvider 
*provider_module )
+io_providers_list_set_module( const FMAPivot *pivot, FMAIOProvider *provider_object, FMAIIOProvider 
*provider_module )
 {
        provider_object->private->provider = g_object_ref( provider_module );
 
        provider_object->private->item_changed_handler =
                        g_signal_connect(
                                        provider_module, IO_PROVIDER_SIGNAL_ITEM_CHANGED,
-                                       ( GCallback ) na_pivot_on_item_changed_handler, ( gpointer ) pivot );
+                                       ( GCallback ) fma_pivot_on_item_changed_handler, ( gpointer ) pivot );
 
        provider_object->private->writable =
                        is_finally_writable( provider_object, pivot, &provider_object->private->reason );
@@ -626,7 +626,7 @@ io_providers_list_set_module( const NAPivot *pivot, FMAIOProvider *provider_obje
 /*
  * fma_io_provider_unref_io_providers_list:
  *
  * Called by on #NAPivot dispose(), free here resources allocated to
  * the I/O providers.
  */
 void
@@ -730,7 +730,7 @@ fma_io_provider_is_available( const FMAIOProvider *provider )
 /*
  * fma_io_provider_is_conf_readable:
  * @provider: this #FMAIOProvider.
  * @pivot: the #NAPivot application object.
  * @mandatory: a pointer to a boolean which will be set to %TRUE if the
  *  preference is mandatory; may be %NULL.
  *
@@ -744,13 +744,13 @@ fma_io_provider_is_available( const FMAIOProvider *provider )
  * - whether this flag has been set as mandatory by an admin.
  */
 gboolean
-fma_io_provider_is_conf_readable( const FMAIOProvider *provider, const NAPivot *pivot, gboolean *mandatory )
+fma_io_provider_is_conf_readable( const FMAIOProvider *provider, const FMAPivot *pivot, gboolean *mandatory )
 {
        gboolean readable;
        gchar *group;
 
        g_return_val_if_fail( FMA_IS_IO_PROVIDER( provider ), FALSE );
-       g_return_val_if_fail( NA_IS_PIVOT( pivot ), FALSE );
+       g_return_val_if_fail( FMA_IS_PIVOT( pivot ), FALSE );
 
        readable = FALSE;
 
@@ -767,7 +767,7 @@ fma_io_provider_is_conf_readable( const FMAIOProvider *provider, const NAPivot *
 /*
  * fma_io_provider_is_conf_writable:
  * @provider: this #FMAIOProvider.
  * @pivot: the #NAPivot application object.
  * @mandatory: a pointer to a boolean which will be set to %TRUE if the
  *  preference is mandatory; may be %NULL.
  *
@@ -783,12 +783,12 @@ fma_io_provider_is_conf_readable( const FMAIOProvider *provider, const NAPivot *
  * FMAIIOProvider module. See also is_willing_to() and is_able_to().
  */
 gboolean
-fma_io_provider_is_conf_writable( const FMAIOProvider *provider, const NAPivot *pivot, gboolean *mandatory )
+fma_io_provider_is_conf_writable( const FMAIOProvider *provider, const FMAPivot *pivot, gboolean *mandatory )
 {
        gboolean is_writable;
 
        g_return_val_if_fail( FMA_IS_IO_PROVIDER( provider ), FALSE );
-       g_return_val_if_fail( NA_IS_PIVOT( pivot ), FALSE );
+       g_return_val_if_fail( FMA_IS_PIVOT( pivot ), FALSE );
 
        is_writable = FALSE;
 
@@ -832,10 +832,10 @@ fma_io_provider_is_finally_writable( const FMAIOProvider *provider, guint *reaso
 
 /*
  * fma_io_provider_load_items:
  * @pivot: the #NAPivot object which owns the list of registered I/O
  *  storage providers.
  * @loadable_set: the set of loadable items
  *  (cf. NAPivotLoadableSet enumeration defined in core/na-pivot.h).
  * @messages: error messages.
  *
  * Loads the tree from I/O storage subsystems.
@@ -847,14 +847,14 @@ fma_io_provider_is_finally_writable( const FMAIOProvider *provider, guint *reaso
  * The returned list should be fma_object_free_items().
  */
 GList *
-fma_io_provider_load_items( const NAPivot *pivot, guint loadable_set, GSList **messages )
+fma_io_provider_load_items( const FMAPivot *pivot, guint loadable_set, GSList **messages )
 {
        static const gchar *thisfn = "fma_io_provider_load_items";
        GList *flat, *hierarchy, *filtered;
        GSList *level_zero;
        guint order_mode;
 
-       g_return_val_if_fail( NA_IS_PIVOT( pivot ), NULL );
+       g_return_val_if_fail( FMA_IS_PIVOT( pivot ), NULL );
 
        g_debug( "%s: pivot=%p, loadable_set=%d, messages=%p",
                        thisfn, ( void * ) pivot, loadable_set, ( void * ) messages );
@@ -942,7 +942,7 @@ dump_providers_list( GList *providers )
 #endif
 
 static gboolean
-is_conf_writable( const FMAIOProvider *provider, const NAPivot *pivot, gboolean *mandatory )
+is_conf_writable( const FMAIOProvider *provider, const FMAPivot *pivot, gboolean *mandatory )
 {
        gchar *group;
        gboolean is_writable;
@@ -959,7 +959,7 @@ is_conf_writable( const FMAIOProvider *provider, const NAPivot *pivot, gboolean
  * This same status may later be reevaluated on demand.
  */
 static gboolean
-is_finally_writable( const FMAIOProvider *provider, const NAPivot *pivot, guint *reason )
+is_finally_writable( const FMAIOProvider *provider, const FMAPivot *pivot, guint *reason )
 {
        static const gchar *thisfn = "fma_io_provider_is_finally_writable";
        gboolean writable;
@@ -1019,7 +1019,7 @@ is_finally_writable( const FMAIOProvider *provider, const NAPivot *pivot, guint
 }
 
 static GList *
-load_items_filter_unwanted_items( const NAPivot *pivot, GList *hierarchy, guint loadable_set )
+load_items_filter_unwanted_items( const FMAPivot *pivot, GList *hierarchy, guint loadable_set )
 {
        GList *it;
        GList *filtered;
@@ -1101,7 +1101,7 @@ load_items_filter_unwanted_items_rec( GList *hierarchy, guint loadable_set )
  * - items (actions or menus) which do not satisfy the defined loadable set
  */
 static GList *
-load_items_get_merged_list( const NAPivot *pivot, guint loadable_set, GSList **messages )
+load_items_get_merged_list( const FMAPivot *pivot, guint loadable_set, GSList **messages )
 {
        const GList *providers;
        const GList *ip;
@@ -1190,7 +1190,7 @@ load_items_hierarchy_build( GList **tree, GSList *level_zero, gboolean list_if_e
 }
 
 static GList *
-load_items_hierarchy_sort( const NAPivot *pivot, GList *tree, GCompareFunc fn )
+load_items_hierarchy_sort( const FMAPivot *pivot, GList *tree, GCompareFunc fn )
 {
        GList *sorted;
        GList *items, *it;
@@ -1238,7 +1238,7 @@ peek_item_by_id_compare( const FMAObject *obj, const gchar *id )
  *
  * Returns: the FMAIIOProvider return code.
  *
  * #NAPivot class, which should be the only caller of this function,
  * has already check that this item is writable, i.e. that all conditions
  * are met to be able to successfully write the item down to the
  * storage subsystem.
@@ -368,7 +368,7 @@ fma_io_provider_find_io_provider_by_id( const NAPivot *pivot, const gchar *id )
 /*
  * fma_io_provider_get_io_providers_list:
- * @pivot: the current #NAPivot instance.
+ * @pivot: the current #FMAPivot instance.
  *
  * Build (if not already done) the write-ordered list of currently
@@ -601,17 +601,17 @@ io_provider_new( const NAPivot *pivot, FMAIIOProvider *module, const gchar *id )
 /*
  * when a IIOProvider plugin is associated with the FMAIOProvider object,
- * we connect the NAPivot callback to the 'item-changed' signal
+ * we connect the FMAPivot callback to the 'item-changed' signal
  */
 static void
@@ -626,7 +626,7 @@ io_providers_list_set_module( const NAPivot *pivot, FMAIOProvider *provider_obje
  * fma_io_provider_unref_io_providers_list:
  *
- * Called by on #NAPivot dispose(), free here resources allocated to
+ * Called by on #FMAPivot dispose(), free here resources allocated to
  * the I/O providers.
  */
@@ -730,7 +730,7 @@ fma_io_provider_is_available( const FMAIOProvider *provider )
  * fma_io_provider_is_conf_readable:
  * @provider: this #FMAIOProvider.
- * @pivot: the #NAPivot application object.
+ * @pivot: the #FMAPivot application object.
  * @mandatory: a pointer to a boolean which will be set to %TRUE if the
  *  preference is mandatory; may be %NULL.
@@ -767,7 +767,7 @@ fma_io_provider_is_conf_readable( const FMAIOProvider *provider, const NAPivot *
  * fma_io_provider_is_conf_writable:
  * @provider: this #FMAIOProvider.
- * @pivot: the #NAPivot application object.
+ * @pivot: the #FMAPivot application object.
  * @mandatory: a pointer to a boolean which will be set to %TRUE if the
  *  preference is mandatory; may be %NULL.
@@ -832,10 +832,10 @@ fma_io_provider_is_finally_writable( const FMAIOProvider *provider, guint *reaso
 /*
  * fma_io_provider_load_items:
- * @pivot: the #NAPivot object which owns the list of registered I/O
+ * @pivot: the #FMAPivot object which owns the list of registered I/O
  *  storage providers.
  * @loadable_set: the set of loadable items
@@ -832,10 +832,10 @@ fma_io_provider_is_finally_writable( const FMAIOProvider *provider, guint *reaso
  *  storage providers.
  * @loadable_set: the set of loadable items
- *  (cf. NAPivotLoadableSet enumeration defined in core/na-pivot.h).
+ *  (cf. FMAPivotLoadableSet enumeration defined in core/fma-pivot.h).
  * @messages: error messages.
  *
@@ -1238,7 +1238,7 @@ peek_item_by_id_compare( const FMAObject *obj, const gchar *id )
  * Returns: the FMAIIOProvider return code.
  *
- * #NAPivot class, which should be the only caller of this function,
+ * #FMAPivot class, which should be the only caller of this function,
  * has already check that this item is writable, i.e. that all conditions
  * are met to be able to successfully write the item down to the
diff --git a/src/core/na-pivot.h b/src/core/fma-pivot.h
similarity index 58%
rename from src/core/na-pivot.h
rename to src/core/fma-pivot.h
index 8858883..acec270 100644
--- a/src/core/na-pivot.h
+++ b/src/core/fma-pivot.h
@@ -27,26 +27,26 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __CORE_NA_PIVOT_H__
-#define __CORE_NA_PIVOT_H__
+#ifndef __CORE_FMA_PIVOT_H__
+#define __CORE_FMA_PIVOT_H__
 
 /* @title: NAPivot
  * @short_description: The #NAPivot Class Definition
  * @include: core/na-pivot.h
  *
  * A consuming program should allocate one new NAPivot object in its
  * startup phase. The class takes care of declaring the I/O interfaces,
  * while registering the known providers.
- *             NAPivot *pivot = na_pivot_new();
+ *             FMAPivot *pivot = fma_pivot_new();
  *
  * With this newly allocated #NAPivot object, the consuming program
  * is then able to ask for loading the items.
- *             na_pivot_set_loadable( pivot, PIVOT_LOADABLE_SET );
- *             na_pivot_load_items( pivot );
+ *             fma_pivot_set_loadable( pivot, PIVOT_LOADABLE_SET );
+ *             fma_pivot_load_items( pivot );
  *
  * Notification system.
  *
  * The NAPivot object acts as a sort of "summarizing relay" for notification
  * messages sent by I/O storage providers:
  *
  * - When an I/O storage subsystem detects a change on an item it manages,
@@ -60,11 +60,11 @@
  *   anything with the signal name, but has only to take care of calling
  *   a function of the FMAIIOProvider API.
  *
  * - The emitted signal is catched by na_pivot_on_item_changed_handler(),
  *   which was connected when the I/O provider plugin was associated with
  *   the FMAIOProvider object.
  *
  * - The NAPivot object receives these notifications originating from all
  *   loaded I/O providers, itself summarizes them, and only then notify its
  *   consumers with only one message for a whole set of modifications.
  *
@@ -79,32 +79,32 @@
 
 G_BEGIN_DECLS
 
-#define NA_TYPE_PIVOT                ( na_pivot_get_type())
-#define NA_PIVOT( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, NA_TYPE_PIVOT, NAPivot ))
-#define NA_PIVOT_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, NA_TYPE_PIVOT, NAPivotClass ))
-#define NA_IS_PIVOT( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_TYPE_PIVOT ))
-#define NA_IS_PIVOT_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NA_TYPE_PIVOT ))
-#define NA_PIVOT_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), NA_TYPE_PIVOT, NAPivotClass ))
+#define FMA_TYPE_PIVOT                ( fma_pivot_get_type())
+#define FMA_PIVOT( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, FMA_TYPE_PIVOT, FMAPivot ))
+#define FMA_PIVOT_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, FMA_TYPE_PIVOT, FMAPivotClass ))
+#define FMA_IS_PIVOT( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, FMA_TYPE_PIVOT ))
+#define FMA_IS_PIVOT_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), FMA_TYPE_PIVOT ))
+#define FMA_PIVOT_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), FMA_TYPE_PIVOT, FMAPivotClass 
))
 
-typedef struct _NAPivotPrivate       NAPivotPrivate;
+typedef struct _FMAPivotPrivate       FMAPivotPrivate;
 
 typedef struct {
        /*< private >*/
-       GObject         parent;
-       NAPivotPrivate *private;
+       GObject          parent;
+       FMAPivotPrivate *private;
 }
-       NAPivot;
+       FMAPivot;
 
-typedef struct _NAPivotClassPrivate  NAPivotClassPrivate;
+typedef struct _FMAPivotClassPrivate  FMAPivotClassPrivate;
 
 typedef struct {
        /*< private >*/
-       GObjectClass         parent;
-       NAPivotClassPrivate *private;
+       GObjectClass          parent;
+       FMAPivotClassPrivate *private;
 }
-       NAPivotClass;
+       FMAPivotClass;
 
-GType    na_pivot_get_type( void );
+GType    fma_pivot_get_type( void );
 
 /* properties
  */
@@ -113,12 +113,12 @@ GType    na_pivot_get_type( void );
 
 /* signals
  *
  * NAPivot acts as a 'summarizing' proxy for signals emitted by the
  * FMAIIOProvider providers when they detect a modification in their
  * underlying items storage subsystems.
  *
  * As several to many signals may be emitted when such a modification occurs,
  * NAPivot summarizes all these signals in an only one 'items-changed' event.
  */
 #define PIVOT_SIGNAL_ITEMS_CHANGED                             "pivot-items-changed"
 
@@ -132,30 +132,30 @@ typedef enum {
        PIVOT_LOAD_INVALID  = 1 << 1,
        PIVOT_LOAD_ALL      = 0xff
 }
-       NAPivotLoadableSet;
+       FMAPivotLoadableSet;
 
-NAPivot      *na_pivot_new ( void );
-void          na_pivot_dump( const NAPivot *pivot );
+FMAPivot      *fma_pivot_new                    ( void );
+void           fma_pivot_dump                   ( const FMAPivot *pivot );
 
 /* Management of the plugins which claim to implement a FileManager-Actions interface.
  * As of 2.30, these may be FMAIIOProvider, FMAIImporter or FMAIExporter
  */
-GList        *na_pivot_get_providers ( const NAPivot *pivot, GType type );
-void          na_pivot_free_providers( GList *providers );
+GList         *fma_pivot_get_providers          ( const FMAPivot *pivot, GType type );
+void           fma_pivot_free_providers         ( GList *providers );
 
 /* Items, menus and actions, management
  */
-FMAObjectItem *na_pivot_get_item     ( const NAPivot *pivot, const gchar *id );
-GList        *na_pivot_get_items    ( const NAPivot *pivot );
-void          na_pivot_load_items   ( NAPivot *pivot );
-void          na_pivot_set_new_items( NAPivot *pivot, GList *tree );
+FMAObjectItem *fma_pivot_get_item               ( const FMAPivot *pivot, const gchar *id );
+GList         *fma_pivot_get_items              ( const FMAPivot *pivot );
+void           fma_pivot_load_items             ( FMAPivot *pivot );
+void           fma_pivot_set_new_items          ( FMAPivot *pivot, GList *tree );
 
-void          na_pivot_on_item_changed_handler( FMAIIOProvider *provider, NAPivot *pivot  );
+void           fma_pivot_on_item_changed_handler( FMAIIOProvider *provider, FMAPivot *pivot  );
 
 /* NAPivot properties and configuration
  */
-void          na_pivot_set_loadable     ( NAPivot *pivot, guint loadable );
+void           fma_pivot_set_loadable           ( FMAPivot *pivot, guint loadable );
 
 G_END_DECLS
 
-#endif /* __CORE_NA_PIVOT_H__ */
+#endif /* __CORE_FMA_PIVOT_H__ */
@@ -27,26 +27,26 @@
 
-/* @title: NAPivot
- * @short_description: The #NAPivot Class Definition
- * @include: core/na-pivot.h
+/* @title: FMAPivot
+ * @short_description: The #FMAPivot Class Definition
+ * @include: core/fma-pivot.h
  *
@@ -27,26 +27,26 @@
  *
- * A consuming program should allocate one new NAPivot object in its
+ * A consuming program should allocate one new FMAPivot object in its
  * startup phase. The class takes care of declaring the I/O interfaces,
  * while registering the known providers.
@@ -27,26 +27,26 @@
  *
- * With this newly allocated #NAPivot object, the consuming program
+ * With this newly allocated #FMAPivot object, the consuming program
  * is then able to ask for loading the items.
@@ -27,26 +27,26 @@
  * Notification system.
  *
- * The NAPivot object acts as a sort of "summarizing relay" for notification
+ * The FMAPivot object acts as a sort of "summarizing relay" for notification
  * messages sent by I/O storage providers:
  *
@@ -60,11 +60,11 @@
  *   a function of the FMAIIOProvider API.
  *
- * - The emitted signal is catched by na_pivot_on_item_changed_handler(),
+ * - The emitted signal is catched by fma_pivot_on_item_changed_handler(),
  *   which was connected when the I/O provider plugin was associated with
  *   the FMAIOProvider object.
@@ -60,11 +60,11 @@
  *   the FMAIOProvider object.
  *
- * - The NAPivot object receives these notifications originating from all
+ * - The FMAPivot object receives these notifications originating from all
  *   loaded I/O providers, itself summarizes them, and only then notify its
  *   consumers with only one message for a whole set of modifications.
@@ -113,12 +113,12 @@ GType    na_pivot_get_type( void );
 /* signals
  *
- * NAPivot acts as a 'summarizing' proxy for signals emitted by the
+ * FMAPivot acts as a 'summarizing' proxy for signals emitted by the
  * FMAIIOProvider providers when they detect a modification in their
  * underlying items storage subsystems.
@@ -113,12 +113,12 @@ GType    na_pivot_get_type( void );
  *
  * As several to many signals may be emitted when such a modification occurs,
- * NAPivot summarizes all these signals in an only one 'items-changed' event.
+ * FMAPivot summarizes all these signals in an only one 'items-changed' event.
  */
 #define PIVOT_SIGNAL_ITEMS_CHANGED                             "pivot-items-changed"
@@ -132,30 +132,30 @@ typedef enum {
 
-/* NAPivot properties and configuration
+/* FMAPivot properties and configuration
  */
diff --git a/src/core/na-updater.h b/src/core/na-updater.h
index 395e76b..58e32a0 100644
--- a/src/core/na-updater.h
+++ b/src/core/na-updater.h
@@ -34,11 +34,11 @@
  * @short_description: The #NAUpdater Class Definition
  * @include: core/na-updater.h
  *
  * #NAUpdater is a #NAPivot-derived class which allows its clients
  * to update actions and menus.
  */
 
-#include "na-pivot.h"
+#include "fma-pivot.h"
 
 G_BEGIN_DECLS
 
@@ -53,7 +53,7 @@ typedef struct _NAUpdaterPrivate       NAUpdaterPrivate;
 
 typedef struct {
        /*< private >*/
-       NAPivot           parent;
+       FMAPivot           parent;
        NAUpdaterPrivate *private;
 }
        NAUpdater;
@@ -62,7 +62,7 @@ typedef struct _NAUpdaterClassPrivate  NAUpdaterClassPrivate;
 
 typedef struct {
        /*< private >*/
-       NAPivotClass           parent;
+       FMAPivotClass           parent;
        NAUpdaterClassPrivate *private;
 }
        NAUpdaterClass;
@@ -34,11 +34,11 @@
  * @include: core/na-updater.h
  *
- * #NAUpdater is a #NAPivot-derived class which allows its clients
+ * #NAUpdater is a #FMAPivot-derived class which allows its clients
  * to update actions and menus.
  */
diff --git a/src/plugin-menu/nautilus-actions.c b/src/plugin-menu/nautilus-actions.c
index d65344d..de578af 100644
--- a/src/plugin-menu/nautilus-actions.c
+++ b/src/plugin-menu/nautilus-actions.c
@@ -43,7 +43,7 @@
 #include <api/fma-object-api.h>
 #include <api/fma-timeout.h>
 
-#include <core/na-pivot.h>
+#include <core/fma-pivot.h>
 #include <core/fma-about.h>
 #include <core/na-selected-info.h>
 #include <core/na-tokens.h>
@@ -60,7 +60,7 @@ struct _NautilusActionsClassPrivate {
  */
 struct _NautilusActionsPrivate {
        gboolean  dispose_has_run;
-       NAPivot  *pivot;
+       FMAPivot  *pivot;
        gulong    items_changed_handler;
        gulong    settings_changed_handler;
        FMATimeout change_timeout;
@@ -102,7 +102,7 @@ static GList            *create_root_menu( NautilusActions *plugin, GList *nauti
 static GList            *add_about_item( NautilusActions *plugin, GList *nautilus_menu );
 static void              execute_about( NautilusMenuItem *item, NautilusActions *plugin );
 
-static void              on_pivot_items_changed_handler( NAPivot *pivot, NautilusActions *plugin );
+static void              on_pivot_items_changed_handler( FMAPivot *pivot, NautilusActions *plugin );
 static void              on_settings_key_changed_handler( const gchar *group, const gchar *key, 
gconstpointer new_value, gboolean mandatory, NautilusActions *plugin );
 static void              on_change_event_timeout( NautilusActions *plugin );
 
@@ -190,7 +190,7 @@ instance_init( GTypeInstance *instance, gpointer klass )
  * We have to react to some runtime environment modifications:
  *
  * - whether the items list has changed (we have to reload a new pivot)
  *   > registering for notifications against NAPivot
  *
  * - whether to add the 'About FileManager-Actions' item
  * - whether to create a 'FileManager-Actions actions' root menu
@@ -215,14 +215,14 @@ instance_constructed( GObject *object )
 
                g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
-               priv->pivot = na_pivot_new();
+               priv->pivot = fma_pivot_new();
 
                /* setup NAPivot properties before loading items
                 */
-               na_pivot_set_loadable( priv->pivot, !PIVOT_LOAD_DISABLED & !PIVOT_LOAD_INVALID );
-               na_pivot_load_items( priv->pivot );
+               fma_pivot_set_loadable( priv->pivot, !PIVOT_LOAD_DISABLED & !PIVOT_LOAD_INVALID );
+               fma_pivot_load_items( priv->pivot );
 
                /* register against NAPivot to be notified of items changes
                 */
                priv->items_changed_handler =
                                g_signal_connect( priv->pivot,
@@ -495,11 +495,11 @@ build_nautilus_menu( NautilusActions *plugin, guint target, GList *selection )
        gboolean items_add_about_item;
        gboolean items_create_root_menu;
 
-       g_return_val_if_fail( NA_IS_PIVOT( plugin->private->pivot ), NULL );
+       g_return_val_if_fail( FMA_IS_PIVOT( plugin->private->pivot ), NULL );
 
        tokens = na_tokens_new_from_selection( selection );
 
-       tree = na_pivot_get_items( plugin->private->pivot );
+       tree = fma_pivot_get_items( plugin->private->pivot );
        g_debug( "%s: tree=%p, count=%d", thisfn, ( void * ) tree, g_list_length( tree ));
 
        nautilus_menu = build_nautilus_menu_rec( tree, target, selection, tokens );
@@ -613,7 +613,7 @@ build_nautilus_menu_rec( GList *tree, guint target, GList *selection, NATokens *
 
 /*
  * expand_tokens_item:
  * @item: a FMAObjectItem read from the NAPivot.
  * @tokens: the NATokens object which holds current selection data
  *  (uris, basenames, mimetypes, etc.)
  *
@@ -1008,20 +1008,20 @@ execute_about( NautilusMenuItem *item, NautilusActions *plugin )
  * Not only the items list itself, but also several runtime preferences have
  * an effect on the display of items in file manager context menu.
  *
  * We of course monitor here all these informations; only asking NAPivot
  * for reloading its items when we detect the end of a burst of changes.
  *
  * Only when NAPivot has finished with reloading its items list, then we
  * inform the file manager that its items list has changed.
  */
 
 /* signal emitted by NAPivot at the end of a burst of 'item-changed' signals
  * from i/o providers
  */
 static void
-on_pivot_items_changed_handler( NAPivot *pivot, NautilusActions *plugin )
+on_pivot_items_changed_handler( FMAPivot *pivot, NautilusActions *plugin )
 {
-       g_return_if_fail( NA_IS_PIVOT( pivot ));
+       g_return_if_fail( FMA_IS_PIVOT( pivot ));
        g_return_if_fail( NAUTILUS_IS_ACTIONS( plugin ));
 
        if( !plugin->private->dispose_has_run ){
@@ -1054,6 +1054,6 @@ on_change_event_timeout( NautilusActions *plugin )
        static const gchar *thisfn = "nautilus_actions_on_change_event_timeout";
        g_debug( "%s: timeout expired", thisfn );
 
-       na_pivot_load_items( plugin->private->pivot );
+       fma_pivot_load_items( plugin->private->pivot );
        nautilus_menu_provider_emit_items_updated_signal( NAUTILUS_MENU_PROVIDER( plugin ));
 }
@@ -190,7 +190,7 @@ instance_init( GTypeInstance *instance, gpointer klass )
  *
  * - whether the items list has changed (we have to reload a new pivot)
- *   > registering for notifications against NAPivot
+ *   > registering for notifications against FMAPivot
  *
  * - whether to add the 'About FileManager-Actions' item
@@ -215,14 +215,14 @@ instance_constructed( GObject *object )
 
-               /* setup NAPivot properties before loading items
+               /* setup FMAPivot properties before loading items
                 */
@@ -215,14 +215,14 @@ instance_constructed( GObject *object )
 
-               /* register against NAPivot to be notified of items changes
+               /* register against FMAPivot to be notified of items changes
                 */
                priv->items_changed_handler =
@@ -613,7 +613,7 @@ build_nautilus_menu_rec( GList *tree, guint target, GList *selection, NATokens *
 /*
  * expand_tokens_item:
- * @item: a FMAObjectItem read from the NAPivot.
+ * @item: a FMAObjectItem read from the FMAPivot.
  * @tokens: the NATokens object which holds current selection data
  *  (uris, basenames, mimetypes, etc.)
@@ -1008,20 +1008,20 @@ execute_about( NautilusMenuItem *item, NautilusActions *plugin )
  * an effect on the display of items in file manager context menu.
  *
- * We of course monitor here all these informations; only asking NAPivot
+ * We of course monitor here all these informations; only asking FMAPivot
  * for reloading its items when we detect the end of a burst of changes.
  *
@@ -1008,20 +1008,20 @@ execute_about( NautilusMenuItem *item, NautilusActions *plugin )
  * for reloading its items when we detect the end of a burst of changes.
  *
- * Only when NAPivot has finished with reloading its items list, then we
+ * Only when FMAPivot has finished with reloading its items list, then we
  * inform the file manager that its items list has changed.
  */
@@ -1008,20 +1008,20 @@ execute_about( NautilusMenuItem *item, NautilusActions *plugin )
  */
 
-/* signal emitted by NAPivot at the end of a burst of 'item-changed' signals
+/* signal emitted by FMAPivot at the end of a burst of 'item-changed' signals
  * from i/o providers
  */
diff --git a/src/utils/nautilus-actions-run.c b/src/utils/nautilus-actions-run.c
index 04846d6..84ac9db 100644
--- a/src/utils/nautilus-actions-run.c
+++ b/src/utils/nautilus-actions-run.c
@@ -42,7 +42,7 @@
 #include <api/fma-dbus.h>
 
 #include <core/fma-gconf-migration.h>
-#include <core/na-pivot.h>
+#include <core/fma-pivot.h>
 #include <core/na-selected-info.h>
 #include <core/na-tokens.h>
 
@@ -101,7 +101,7 @@ main( int argc, char** argv )
 
        /* pwi 2011-01-05
         * run GConf migration tools before doing anything else
         * above all before allocating a new NAPivot
         */
        fma_gconf_migration_run();
 
@@ -221,16 +221,16 @@ init_options( void )
 static FMAObjectAction *
 get_action( const gchar *id )
 {
-       NAPivot *pivot;
+       FMAPivot *pivot;
        FMAObjectAction *action;
 
        action = NULL;
 
-       pivot = na_pivot_new();
-       na_pivot_set_loadable( pivot, !PIVOT_LOAD_DISABLED & !PIVOT_LOAD_INVALID );
-       na_pivot_load_items( pivot );
+       pivot = fma_pivot_new();
+       fma_pivot_set_loadable( pivot, !PIVOT_LOAD_DISABLED & !PIVOT_LOAD_INVALID );
+       fma_pivot_load_items( pivot );
 
-       action = ( FMAObjectAction * ) na_pivot_get_item( pivot, id );
+       action = ( FMAObjectAction * ) fma_pivot_get_item( pivot, id );
 
        if( !action ){
                g_printerr( _( "Error: action '%s' doesn't exist.\n" ), id );
@@ -101,7 +101,7 @@ main( int argc, char** argv )
        /* pwi 2011-01-05
         * run GConf migration tools before doing anything else
-        * above all before allocating a new NAPivot
+        * above all before allocating a new FMAPivot
         */
        fma_gconf_migration_run();


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]